OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Impor kontak",
    "Details" : "Detil",
    "All contacts" : "Semua kontak",
    "_Imported %n contact_::_Imported %n contacts_" : ["Mengimpor %n kontak"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(melewati %n kontak)"],
    "Contacts" : "Kontak",
    "A contacts app for Nextcloud" : "Sebuah aplikasi kontak untuk Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Aplikasi kontak Nextcloud adalah antarmuka pengguna untuk server CardDAV Nextcloud. Sinkronkan kontak dengan mudah dari berbagai perangkat dengan Nextcloud Anda dan edit secara daring.\n\n* 🚀 **Integrasi dengan aplikasi Nextcloud lainnya!** Saat ini Mail dan Calendar – akan ada lebih banyak lagi.\n* 🎉 **Jangan pernah lupa ulang tahun!** Anda dapat menyinkronkan ulang tahun dan acara berulang lainnya dengan Kalender Nextcloud Anda.\n* 👥 **Berbagi Buku Alamat!** Anda ingin membagikan kontak Anda dengan teman atau rekan kerja? Tidak masalah!\n* 🙈 **Kami tidak menemukan kembali roda!** Berdasarkan pustaka SabreDAV yang hebat dan terbuka.",
    "Copy to full name" : "Salin ke nama lengkap",
    "Omit year" : "Hilangkan tahun",
    "Allow updating avatars from social media" : "Izinkan pembaruan avatar dari media sosial",
    "There was an error fetching the member list" : "Terjadi kesalahan saat mengambil daftar anggota",
    "Please select a team" : "Silakan pilih tim",
    "Loading team…" : "Memuat tim…",
    "Loading contacts …" : "Memuat kontak …",
    "There are no contacts yet" : "Belum ada kontak",
    "Create contact" : "Buat kontak",
    "There are no contacts in this group" : "Tidak ada kontak dalam grup ini",
    "Create contacts" : "Buat kontak",
    "Add contacts" : "Tambahkan kontak",
    "Loading …" : "Memuat …",
    "Manage team" : "Kelola tim",
    "Leave team" : "Tinggalkan tim",
    "Delete team" : "Hapus tim",
    "Setting saved" : "Pengaturan disimpan",
    "Failed to save setting" : "Gagal menyimpan pengaturan",
    "Contacts settings" : "Pengaturan kontak",
    "General" : "Umum",
    "Update avatars from social media" : "Perbarui avatar dari media sosial",
    "Refreshed once per week" : "Disegarkan sekali per minggu",
    "Address books" : "Buku alamat",
    "Rename" : "Ubah nama",
    "Export" : "Ekspor",
    "Send email" : "Kirim email",
    "Send email as BCC" : "Kirim email sebagai BCC",
    "Delete" : "Hapus",
    "Show all groups" : "Tampilkan semua grup",
    "Collapse groups" : "Ciutkan grup",
    "Show all teams" : "Tampilkan semua tim",
    "Collapse teams" : "Ciutkan tim",
    "Group name cannot be empty" : "Nama grup tidak boleh kosong",
    "This group already exists" : "Grup ini sudah ada",
    "An error occurred while creating the group" : "Terjadi kesalahan saat membuat grup",
    "This team already exists" : "Tim ini sudah ada",
    "An error happened during the creation of the team" : "Terjadi kesalahan saat pembuatan tim",
    "Recently contacted" : "Baru dihubungi",
    "Contact groups" : "Grup kontak",
    "Create a new contact group" : "Buat grup kontak baru",
    "Contact group name" : "Nama grup kontak",
    "Teams" : "Tim",
    "Create a new team" : "Buat tim baru",
    "Open the contacts app settings" : "Buka pengaturan aplikasi kontak",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Dibagikan dengan {num} entitas"],
    "Copied" : "Disalin",
    "Cannot copy" : "Tidak dapat menyalin",
    "Copy link" : "Salin tautan",
    "Toggling of address book was not successful" : "Pengalihan buku alamat tidak berhasil",
    "This will delete the address book and every contacts within it" : "Ini akan menghapus buku alamat dan setiap kontak di dalamnya",
    "Delete {addressbook}?" : "Hapus {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Ini akan berhenti membagikan buku alamat dan setiap kontak di dalamnya",
    "Unshare {addressbook}?" : "Berhenti membagikan {addressbook}?",
    "Deletion of address book was not successful." : "Penghapusan buku alamat tidak berhasil.",
    "Renaming of address book was not successful." : "Penggantian nama buku alamat tidak berhasil.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Tersembunyi)",
    "Download" : "Unduh",
    "Show" : "Tampilkan",
    "Unshare from me" : "Berhenti berbagi dari saya",
    "_%n contact_::_%n contacts_" : ["%n kontak"],
    "_%n group_::_%n groups_" : ["%n grup"],
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "Share with users" : "Bagikan dengan pengguna",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "Unable to delete the share" : "Tidak dapat menghapus berbagi",
    "Unable to change permissions" : "Tidak dapat mengubah izin",
    "Choose a vCard file to import" : "Pilih berkas vCard untuk diimpor",
    "Import into the {addressbookName} address book" : "Impor ke buku alamat {addressbookName}",
    "Select local file" : "Pilih berkas lokal",
    "Import from files" : "Impor dari berkas",
    "Importing is disabled because there are no address books available" : "Impor dinonaktifkan karena tidak ada buku alamat yang tersedia",
    "An error occurred, unable to create the address book" : "Terjadi kesalahan, tidak dapat membuat buku alamat",
    "New address book" : "Buku alamat baru",
    "Add new address book" : "Tambahkan buku alamat baru",
    "Cancel" : "Membatalkan",
    "Add" : "Masukkan",
    "First name" : "Nama depan",
    "Last name" : "Nama belakang",
    "Phonetic first name" : "Nama depan fonetik",
    "Phonetic last name" : "Nama belakang fonetik",
    "Display name" : "Nama tampilan",
    "Last modified" : "Terakhir diubah",
    "Sort contacts by" : "Urutkan kontak berdasarkan",
    "Manages" : "Mengelola",
    "Oversees" : "Mengawasi",
    "An error happened during the config change" : "Terjadi kesalahan saat perubahan konfigurasi",
    "Enforce password protection on files shared to this team" : "Terapkan perlindungan kata sandi pada berkas yang dibagikan ke tim ini",
    "Use a unique password for all shares to this team" : "Gunakan kata sandi unik untuk semua berbagi ke tim ini",
    "Unique password …" : "Kata sandi unik …",
    "Save" : "Simpan",
    "Change unique password" : "Ubah kata sandi unik",
    "Failed to save password. Please try again later." : "Gagal menyimpan kata sandi. Silakan coba lagi nanti.",
    "Close" : "Tutup",
    "There is no description for this team" : "Tidak ada deskripsi untuk tim ini",
    "Enter a description for the team" : "Masukkan deskripsi untuk tim",
    "Folder" : "Folder",
    "New folder" : "Folder baru",
    "Folder name" : "Nama Folder",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Ini akan membuat folder reguler yang dibagikan dengan tim. Untuk membuat Folder Tim, silakan hubungi administrator {productName} Anda",
    "Talk conversation" : "Percakapan Talk",
    "New Talk conversation" : "Percakapan Talk baru",
    "Conversation name" : "Nama percakapan",
    "Collective" : "Kolektif",
    "Calendar" : "Kalender",
    "New calendar" : "Kalender baru",
    "Calendar name" : "Nama kalender",
    "Deck board" : "Papan Deck",
    "New Deck board" : "Papan Deck baru",
    "Board name" : "Nama papan",
    "Deck app is not installed. Please install it to create team boards." : "Aplikasi Deck tidak terpasang. Silakan pasang untuk membuat papan tim.",
    "Unknown resource type" : "Jenis sumber daya tidak dikenal",
    "Team calendar \"{resourceName}\" created and shared with team" : "Kalender tim \"{resourceName}\" dibuat dan dibagikan dengan tim",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" dibuat dan dibagikan dengan tim",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalender bernama \"{name}\" sudah ada. Silakan pilih nama yang berbeda.",
    "Failed to create {resourceType}: {error}" : "Gagal membuat {resourceType}: {error}",
    "An error happened while saving {fields}" : "Terjadi kesalahan saat menyimpan {fields}",
    "Team name" : "Nama tim",
    "Team owner" : "Pemilik tim",
    "Edit" : "Edit",
    "Request to join" : "Minta untuk bergabung",
    "Create" : "Membuat",
    "Show in Calendar" : "Tampilkan di Kalender",
    "Your request to join this team is pending approval" : "Permintaan Anda untuk bergabung dengan tim ini menunggu persetujuan",
    "You are not a member of {circle}" : "Anda bukan anggota dari {circle}",
    "Members" : "Anggota",
    "Confirm" : "Konfirmasi",
    "Add more info" : "Tambahkan info lebih lanjut",
    "More fields" : "Bidang lebih banyak",
    "Please select a valid format" : "Silakan pilih format yang valid",
    "Invalid image" : "Gambar tidak sah",
    "Error cropping picture" : "Kesalahan memotong gambar",
    "Pick an avatar" : "Pilih avatar",
    "Pick" : "Pilih",
    "Error while processing the picture." : "Kesalahan saat memproses gambar.",
    "Avatar downloaded from social network" : "Avatar diunduh dari jejaring sosial",
    "Avatar already up to date" : "Avatar sudah terkini",
    "Avatar download failed" : "Unduhan avatar gagal",
    "Crop contact photo" : "Potong foto kontak",
    "Upload a new picture" : "Unggah gambar baru",
    "Choose from Files" : "Pilih dari Berkas",
    "Download picture" : "Unduh gambar",
    "Delete picture" : "Hapus gambar",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontak ini dalam mode baca-saja. Anda tidak memiliki izin untuk mengedit kontak ini.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontak yang Anda coba edit telah berubah. Silakan segarkan kontak secara manual. Setiap pengeditan lebih lanjut akan diabaikan.",
    "Address book" : "Buku alamat",
    "Add contact to Birthday Calendar" : "Tambahkan kontak ke Kalender Ulang Tahun",
    "Exclude contact from Birthday Calendar" : "Kecualikan kontak dari Kalender Ulang Tahun",
    "{title} at {organization}" : "{title} di {organization}",
    "Name" : "Nama",
    "Syntax error. Cannot open the contact." : "Kesalahan sintaks. Tidak dapat membuka kontak.",
    "The contact does not exist on the server anymore." : "Kontak tidak ada lagi di server.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Tidak dapat mengambil kontak dari server, silakan periksa koneksi jaringan Anda.",
    "An error occurred while trying to move the contact" : "Terjadi kesalahan saat mencoba memindahkan kontak",
    "An error occurred while trying to copy the contact" : "Terjadi kesalahan saat mencoba menyalin kontak",
    "Unable to update contact" : "Tidak dapat memperbarui kontak",
    "No contact selected" : "Tidak ada kontak yang dipilih",
    "Select a contact on the list to begin" : "Pilih kontak di daftar untuk memulai",
    "Title" : "Judul",
    "Company" : "Perusahaan",
    "Go to talk conversation" : "Pergi ke percakapan talk",
    "View profile" : "Lihat profil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Kontak ini rusak dan telah diperbaiki. Silakan tinjau konten dan klik di sini untuk menyimpannya.",
    "Edit profile" : "Ubah profil",
    "Clone contact" : "Gandakan kontak",
    "Generate QR Code" : "Buat Kode QR",
    "Contact vCard as QR code" : "Kontak vCard sebagai kode QR",
    "Pick an address book" : "Pilih buku alamat",
    "Select address book" : "Pilih buku alamat",
    "Media shares with you" : "Media berbagi dengan Anda",
    "Talk conversations with you" : "Percakapan Talk dengan Anda",
    "Calendar events with you" : "Acara kalender dengan Anda",
    "Deck cards with you" : "Kartu Deck dengan Anda",
    "No shared items with this contact" : "Tidak ada item yang dibagikan dengan kontak ini",
    "This contact cannot be moved" : "Kontak ini tidak dapat dipindahkan",
    "This contact cannot be grouped" : "Kontak ini tidak dapat dikelompokkan",
    "Add contacts to groups" : "Tambahkan kontak ke grup",
    "Move contacts to addressbook" : "Pindahkan kontak ke buku alamat",
    "Select groups" : "Pilih grup",
    "Select addressbook" : "Pilih buku alamat",
    "Selected contacts" : "Kontak yang dipilih",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Harap diperhatikan bahwa hanya {count} dari {total} kontak yang dapat ditambahkan ke grup",
    "Please note that only {count} of the {total} contacts can be moved" : "Harap diperhatikan bahwa hanya {count} dari {total} kontak yang dapat dipindahkan",
    "Move" : "Move",
    "from {addressbook}" : "dari {addressbook}",
    "Confirm merging contacts" : "Konfirmasi penggabungan kontak",
    "The selected contacts have conflicting information. Choose which information to keep" : "Kontak yang dipilih memiliki informasi yang bertentangan. Pilih informasi mana yang akan disimpan",
    "Contacts can be merged" : "Kontak dapat digabungkan",
    "Groups" : "Grup",
    "Select groups to add the merged contact to" : "Pilih grup untuk menambahkan kontak yang digabungkan",
    "Merge contacts" : "Gabungkan kontak",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Hapus {number} kontak"],
    "Please select at least one editable contact to delete" : "Silakan pilih setidaknya satu kontak yang dapat diedit untuk dihapus",
    "Please select two editable contacts to merge" : "Silakan pilih dua kontak yang dapat diedit untuk digabungkan",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Tambahkan {number} kontak ke grup"],
    "Please select at least one editable contact to add to a group" : "Silakan pilih setidaknya satu kontak yang dapat diedit untuk ditambahkan ke grup",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Pindahkan {number} kontak ke buku alamat"],
    "Please select at least one editable contact to move to an addressbook" : "Silakan pilih setidaknya satu kontak yang dapat diedit untuk dipindahkan ke buku alamat",
    "Are you sure you want to proceed?" : "Apakah Anda yakin ingin melanjutkan?",
    "Add contacts to group" : "Tambahkan kontak ke grup",
    "Search contacts …" : "Cari kontak …",
    "Unselect {number}" : "Batalkan pilihan {number}",
    "Add to {group}" : "Tambahkan ke {group}",
    "Add members to {group}" : "Tambahkan anggota ke {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Harap diperhatikan bahwa Anda hanya dapat menambahkan kontak dari buku alamat yang dapat ditulis ke grup kontak. Kontak dari buku alamat baca-saja, seperti buku alamat sistem, tidak dapat ditambahkan.",
    "Remove {type}" : "Hapus {type}",
    "Add to group" : "Tambahkan ke grup",
    "Add members to group" : "Tambahkan anggota ke grup",
    "Search {types}" : "Cari {types}",
    "Add guest" : "Tambahkan tamu",
    "Search for people to add" : "Cari orang untuk ditambahkan",
    "No results" : "Tidak ada hasil",
    "Add {type}" : "Tambahkan {type}",
    "New team name" : "Nama tim baru",
    "Personal team" : "Tim pribadi",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Tim ini hanya akan terlihat oleh Anda. Anggota lain tidak akan dapat melihat atau menggunakannya.",
    "Local team" : "Tim lokal",
    "This team will not be shared with the other instances of the global scale" : "Tim ini tidak akan dibagikan dengan instansi lain dari skala global",
    "Create team" : "Buat tim",
    "Promote as sole owner" : "Promosikan sebagai pemilik tunggal",
    "Promote to {level}" : "Promosikan ke {level}",
    "Demote to {level}" : "Turunkan ke {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Apakah Anda yakin ingin meninggalkan tim ini? Tindakan ini tidak dapat dibatalkan.",
    "Leave team failed." : "Meninggalkan tim gagal.",
    "Could not delete the member {displayName}" : "Tidak dapat menghapus anggota {displayName}",
    "Could not change the member level to {level}" : "Tidak dapat mengubah tingkat anggota ke {level}",
    "Could not accept membership request" : "Tidak dapat menerima permintaan keanggotaan",
    "Accept membership request" : "Terima permintaan keanggotaan",
    "Reject membership request" : "Tolak permintaan keanggotaan",
    "Manage level" : "Kelola tingkat",
    "Remove member" : "Hapus anggota",
    "Unable to get the results" : "Tidak dapat mendapatkan hasil",
    "Some members could not be added" : "Beberapa anggota tidak dapat ditambahkan",
    "There was an issue adding members to the team" : "Terjadi masalah saat menambahkan anggota ke tim",
    "Loading members list …" : "Memuat daftar anggota …",
    "The list of members is only visible to members of this team" : "Daftar anggota hanya terlihat oleh anggota tim ini",
    "You currently have no access to the member list" : "Anda saat ini tidak memiliki akses ke daftar anggota",
    "Add to {team}" : "Tambahkan ke {team}",
    "Invite members to {team}" : "Undang anggota ke {team}",
    "Pending" : "Tunggu",
    "Select chart …" : "Pilih bagan …",
    "Chart" : "Bagan",
    "Select Date" : "Pilih Tanggal",
    "Select type" : "Pilih jenis",
    "Add contact in group" : "Tambahkan kontak dalam grup",
    "None" : "Tidak ada",
    "copy" : "salin",
    "Select option" : "Pilih opsi",
    "note" : "catatan",
    "email" : "email",
    "send an email" : "kirim email",
    "Personal dates" : "Tanggal pribadi",
    "Add property of this type" : "Tambahkan properti jenis ini",
    "Member" : "Anggota",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Ini adalah grup baca-saja yang dikelola oleh administrator. Anggota grup hanya dapat melihat grup ini.",
    "Unable to create the contact." : "Tidak dapat membuat kontak.",
    "Contact not found" : "Kontak tidak ditemukan",
    "Group {group} not found" : "Grup {group} tidak ditemukan",
    "Add member" : "Tambahkan anggota",
    "New contact" : "Kontak baru",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontak ditambahkan ke {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Menambahkan {success} kontak ke {name}"],
    "_{count} error_::_{count} errors_" : ["{count} kesalahan"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Mengimpor %n kontak ke {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Selesai mengimpor %n kontak ke {addressbook}"],
    "No data for this contact" : "Tidak ada data untuk kontak ini",
    "No data for this contact on their profile" : "Tidak ada data untuk kontak ini di profil mereka",
    "Import" : "Impor",
    "Are you sure you want to import this contact file?" : "Apakah Anda yakin ingin mengimpor berkas kontak ini?",
    "Could not copy" : "Tidak dapat menyalin",
    "Join team" : "Bergabung dengan tim",
    "You are about to leave {circle}.\nAre you sure?" : "Anda akan meninggalkan {circle}.\nApakah Anda yakin?",
    "Please confirm team leave" : "Silakan konfirmasi keluar dari tim",
    "Could not leave the team {displayName}" : "Tidak dapat meninggalkan tim {displayName}",
    "Unable to join the team" : "Tidak dapat bergabung dengan tim",
    "You are about to delete {circle}.\nAre you sure?" : "Anda akan menghapus {circle}.\nApakah Anda yakin?",
    "Please confirm team deletion" : "Silakan konfirmasi penghapusan tim",
    "Unable to delete the team" : "Tidak dapat menghapus tim",
    "Link copied to the clipboard" : "Tautan disalin ke papan klip",
    "Could not copy link to the clipboard." : "Tidak dapat menyalin tautan ke papan klip.",
    "Not grouped" : "Tidak dikelompokkan",
    "Organization chart" : "Bagan organisasi",
    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Tim adalah kelompok orang yang dapat Anda buat sendiri dan dengan siapa Anda dapat berbagi data. Tim dapat terdiri dari akun lain atau grup akun dari instansi Nextcloud, tetapi juga kontak dari buku alamat Anda atau bahkan orang eksternal dengan hanya memasukkan alamat email mereka.",
    "Team" : "Tim",
    "User" : "Pengguna",
    "Group" : "Grup",
    "Email" : "Email",
    "Contact" : "Kontak",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Invites" : "Undangan",
    "Anyone can request membership" : "Siapa pun dapat meminta keanggotaan",
    "Members need to accept invitation" : "Anggota perlu menerima undangan",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Keanggotaan harus dikonfirmasi/diterima oleh Moderator (memerlukan \"Siapa pun dapat meminta keanggotaan\")",
    "Members can also invite" : "Anggota juga dapat mengundang",
    "Membership" : "Keanggotaan",
    "Prevent teams from being a member of another team" : "Cegah tim menjadi anggota tim lain",
    "Privacy" : "Privasi",
    "Visible to everyone" : "Terlihat oleh semua orang",
    "users" : "pengguna",
    "Users" : "Pengguna",
    "groups" : "grup",
    "teams" : "tim",
    "email addresses" : "alamat email",
    "Email addresses" : "Alamat email",
    "contacts" : "kontak",
    "Detailed name" : "Nama lengkap",
    "Additional names" : "Nama tambahan",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Nama panggilan",
    "Notes" : "Catatan",
    "Website" : "Situs Web",
    "Location" : "Lokasi",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Depan",
    "Work" : "Kantor",
    "Other" : "Lainnya",
    "Address" : "Alamat",
    "Post office box" : "PO BOX",
    "Extended address" : "Alamat tambahan",
    "City" : "Kota",
    "State or province" : "Provinsi",
    "Postal code" : "Kode pos",
    "Country" : "Negara",
    "Birthday" : "Tanggal lahir",
    "Place of birth" : "Tempat lahir",
    "Anniversary" : "Ulang tahun",
    "Date of death" : "Tanggal kematian",
    "Place of death" : "Tempat meninggal",
    "Instant messaging" : "Pesan Instan",
    "Phone" : "Telpon",
    "Mobile" : "Ponsel",
    "Work mobile" : "Ponsel kantor",
    "Home mobile" : "Ponsel rumah",
    "Fax" : "Fax",
    "Fax home" : "Fax rumah",
    "Fax work" : "Fax kerja",
    "Pager" : "Pager",
    "Voice" : "Suara",
    "Car" : "Mobil",
    "Work pager" : "Pager kantor",
    "Line manager" : "Manajer lini",
    "Social network" : "Media sosial",
    "Relationship to you" : "Hubungan dengan Anda",
    "Spouse" : "Pasangan",
    "Child" : "Anak",
    "Mother" : "Ibu",
    "Father" : "Ayah",
    "Parent" : "Orang tua",
    "Brother" : "Saudara laki-laki",
    "Sister" : "Saudara perempuan",
    "Relative" : "Kerabat",
    "Friend" : "Teman",
    "Colleague" : "Kolega",
    "Assistant" : "Asisten",
    "Related contacts" : "Kontak terkait",
    "Agent" : "Agen",
    "Emergency" : "Darurat",
    "Co-worker" : "Rekan kerja",
    "Gender" : "Jenis kelamin",
    "Female" : "Perempuan",
    "Male" : "Laki-laki",
    "Unknown" : "Tidak diketahui",
    "Time zone" : "Zona waktu",
    "Spoken languages" : "Bahasa yang digunakan",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontak gagal dibaca"],
    "An error has occurred in team(s). Check the console for more details." : "Terjadi kesalahan pada tim. Periksa konsol untuk detail lebih lanjut.",
    "Unable to create team {circleName}" : "Tidak dapat membuat tim {circleName}",
    "Unable to delete team {circleId}" : "Tidak dapat menghapus tim {circleId}",
    "Unable to delete contact" : "Tidak dapat menghapus kontak"
},
"nplurals=1; plural=0;");
