OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "ئالاقىنى ئەكىرىش",
    "Details" : "تەپسىلاتى",
    "All contacts" : "بارلىق ئالاقىداشلار",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n ئالاقىداش كىرگۈزۈلدى","%n ئالاقىداش كىرگۈزۈلدى"],
    "Contacts" : "ئالاقەداشلار",
    "A contacts app for Nextcloud" : "Nextcloud نىڭ ئالاقىلىشىش دېتالى",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud ئالاقىلىشىش دېتالى Nextcloud نىڭ CardDAV مۇلازىمېتىرى ئۈچۈن ئىشلەتكۈچى كۆرۈنمە يۈزى. Nextcloud بىلەن ھەر خىل ئۈسكۈنىلەرنىڭ ئالاقىسىنى ئاسانلا ماسقەدەملەپ ، توردا تەھرىرلەڭ.\n\n* 🚀 ** باشقا Nextcloud ئەپلىرى بىلەن بىرلەشتۈرۈش! ** ھازىر خەت ۋە كالېندار - تېخىمۇ كۆپ.\n* 🎉 ** تۇغۇلغان كۈننى ھەرگىز ئۇنتۇپ قالماڭ! ** تۇغۇلغان كۈن ۋە باشقا تەكرارلانغان ۋەقەلەرنى كېيىنكى بۇلۇت كالېندارىڭىز بىلەن ماسقەدەملىيەلەيسىز.\n* 👥 ** ئېلان دەپتىرىنى ھەمبەھىرلەش! ** ئالاقىداشلىرىڭىزنى دوستلىرىڭىز ياكى خىزمەتداشلىرىڭىز بىلەن ئورتاقلاشماقچىمۇ؟ چاتاق يوق!\n* 🙈 ** بىز چاقنى ئەسلىگە كەلتۈرمەيمىز! ** ئېسىل ۋە ئوچۇق SabreDAV كۈتۈپخانىسىنى ئاساس قىلغان.",
    "Copy to full name" : "تولۇق ئىسىمغا كۆچۈرۈڭ",
    "Omit year" : "يىلنى چىقىرۋەت",
    "Allow updating avatars from social media" : "ئىجتىمائىي تاراتقۇلاردىكى باش سۈرەتلەرنى يېڭىلاشقا يول قويۇڭ",
    "There was an error fetching the member list" : "ئەزا تىزىملىكىنى ئېلىشتا خاتالىق كۆرۈلدى",
    "Please select a team" : "گۇرۇپپا تاللاڭ",
    "Loading team…" : "يۈك ئەترىتى…",
    "Loading contacts …" : "ئالاقىداشلارنى يۈكلەۋاتىدۇ ...",
    "There are no contacts yet" : "ھازىرچە ھېچقانداق ئالاقە يوق",
    "Create contact" : "ئالاقىلىشىش",
    "There are no contacts in this group" : "بۇ گۇرۇپپىدا ھېچقانداق ئالاقە يوق",
    "Create contacts" : "ئالاقىداش قۇر",
    "Add contacts" : "ئالاقىداش قوشۇڭ",
    "Loading …" : "يۈكلەۋاتىدۇ ...",
    "Manage team" : "گۇرۇپپا باشقۇرۇش",
    "Leave team" : "كوماندىدىن ئايرىلىش",
    "Delete team" : "گۇرۇپپىنى ئۆچۈرۈڭ",
    "Setting saved" : "تەڭشەك ساقلاندى",
    "Failed to save setting" : "تەڭشەكنى ساقلاش مەغلۇب بولدى",
    "Contacts settings" : "ئالاقىلىشىش تەڭشەكلىرى",
    "General" : "ئۇمۇمىي",
    "Update avatars from social media" : "ئىجتىمائىي تاراتقۇلاردىكى باش سۈرەتلەرنى يېڭىلاڭ",
    "Refreshed once per week" : "ھەپتىدە بىر قېتىم يېڭىلىنىدۇ",
    "Address books" : "ئادرېس كىتابلىرى",
    "Rename" : "ئات ئۆزگەرت",
    "Export" : "ئېكسپورت",
    "Send email" : "ئېلېكترونلۇق خەت ئەۋەتىڭ",
    "Send email as BCC" : "ئېلېكترونلۇق خەتنى BCC قىلىپ ئەۋەتىڭ",
    "Delete" : "ئۆچۈر",
    "Show all groups" : "بارلىق گۇرۇپپىلارنى كۆرسەت",
    "Collapse groups" : "گۇرۇپپىلارنى يىمىرىڭ",
    "Show all teams" : "بارلىق كوماندىلارنى كۆرسەت",
    "Collapse teams" : "گۇرۇپپىلارنى يىمىرىڭ",
    "Group name cannot be empty" : "گۇرۇپپا ئىسمى قۇرۇق بولسا بولمايدۇ",
    "This group already exists" : "بۇ گۇرۇپپا مەۋجۇت",
    "An error occurred while creating the group" : "گۇرۇپپا قۇرغاندا خاتالىق كۆرۈلدى",
    "This team already exists" : "بۇ گۇرۇپپا ئاللىبۇرۇن مەۋجۇت",
    "An error happened during the creation of the team" : "گۇرۇپپا قۇرۇش جەريانىدا خاتالىق كۆرۈلدى",
    "Recently contacted" : "يېقىندا ئالاقىلاشتى",
    "Contact groups" : "ئالاقىلىشىش گۇرۇپپىلىرى",
    "Create a new contact group" : "يېڭى ئالاقىلىشىش گۇرۇپپىسى قۇرۇڭ",
    "Contact group name" : "گۇرۇپپا ئىسمى بىلەن ئالاقىلىشىڭ",
    "Teams" : "كوماندىلار",
    "Create a new team" : "يېڭى گۇرۇپپا قۇرۇڭ",
    "Open the contacts app settings" : "ئالاقىداش ئەپ تەڭشىكىنى ئېچىڭ",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} ئورۇنلار بىلەن ئورتاقلىشىلدى","{num} ئورۇنلار بىلەن ئورتاقلىشىلدى"],
    "Copied" : "كۆچۈرۈلگەن",
    "Cannot copy" : "كۆچۈرگىلى بولمايدۇ",
    "Copy link" : "ئۇلانمىنى كۆچۈرۈڭ",
    "Toggling of address book was not successful" : "ئادرېس دەپتىرىنى توغرىلاش مۇۋەپپەقىيەتلىك بولمىدى",
    "This will delete the address book and every contacts within it" : "بۇ ئادرېس دەپتىرىنى ۋە ئۇنىڭدىكى بارلىق ئالاقىلەرنى ئۆچۈرۈۋېتىدۇ",
    "Delete {addressbook}?" : "{addressbook} دەپتىرىنى ئۆچۈرۈڭ؟",
    "This will unshare the address book and every contacts within it" : "بۇ ئادرېس دەپتىرى ۋە ئۇنىڭدىكى بارلىق ئالاقىداشلارنى ئورتاقلاشتۇرىدۇ",
    "Unshare {addressbook}?" : "ئورتاقلاشمىغان {addressbook} دەپتىرى؟",
    "Deletion of address book was not successful." : "ئادرېس دەپتىرىنى ئۆچۈرۈش مۇۋەپپەقىيەتلىك بولمىدى.",
    "Renaming of address book was not successful." : "ئادرېس دەپتىرىنىڭ نامىنى ئۆزگەرتىش مۇۋەپپەقىيەتلىك بولمىدى.",
    "{addressbookname} (Hidden)" : "{addressbookname} (يوشۇرۇن)",
    "Download" : "چۈشۈر",
    "Show" : "كۆرسەت",
    "Unshare from me" : "مەندىن تەڭداشسىز",
    "_%n contact_::_%n contacts_" : ["%n ئالاقىداشلار","%n ئالاقىداشلار"],
    "_%n group_::_%n groups_" : ["%n گۇرۇپپا","%n گۇرۇپپا"],
    "Share with users or groups" : "ئىشلەتكۈچىلەر ياكى گۇرۇپپىلار بىلەن ئورتاقلىشىڭ",
    "Share with users" : "ئىشلەتكۈچىلەر بىلەن ئورتاقلىشىش",
    "No users or groups" : "ئىشلەتكۈچى ياكى گۇرۇپپا يوق",
    "Unable to delete the share" : "ھەمبەھىرنى ئۆچۈرەلمىدى",
    "Unable to change permissions" : "ئىجازەتنى ئۆزگەرتەلمىدى",
    "Choose a vCard file to import" : "ئەكىرىش ئۈچۈن vCard ھۆججىتىنى تاللاڭ",
    "Import into the {addressbookName} address book" : "{addressbookName} ئادرېس دەپتىرىگە ئەكىرىڭ",
    "Select local file" : "يەرلىك ھۆججەتنى تاللاڭ",
    "Import from files" : "ھۆججەتلەردىن ئەكىرىش",
    "Importing is disabled because there are no address books available" : "ئادرېس كىتابلىرى بولمىغاچقا ئىمپورت قىلىش چەكلەنگەن",
    "An error occurred, unable to create the address book" : "ئادرېس دەپتىرىنى قۇرالماسلىقتا خاتالىق كۆرۈلدى",
    "New address book" : "يېڭى ئادرېس دەپتىرى",
    "Add new address book" : "يېڭى ئادرېس دەپتىرىنى قوشۇڭ",
    "Cancel" : "ۋاز كەچ",
    "Add" : "قوش",
    "First name" : "ئاتى",
    "Last name" : "فامىلىسى",
    "Phonetic first name" : "فونېتىكىلىق ئىسمى",
    "Phonetic last name" : "فونېتىكىلىق فامىلىسى",
    "Display name" : "كۆرسىتىش ئىسمى",
    "Last modified" : "ئاخىرقى قېتىم ئۆزگەرتىلگەن",
    "Sort contacts by" : "ئالاقىداشنى بىلەن رەتكە تىز",
    "Manages" : "باشقۇرۇش",
    "Oversees" : "نازارەتچىلەر",
    "An error happened during the config change" : "سەپلىمە ئۆزگەرتىش جەريانىدا خاتالىق كۆرۈلدى",
    "Enforce password protection on files shared to this team" : "بۇ گۇرۇپپىغا ھەمبەھىرلەنگەن ھۆججەتلەردە مەخپىي نومۇر قوغداشنى كۈچەيتىڭ",
    "Use a unique password for all shares to this team" : "بۇ گۇرۇپپىدىكى بارلىق پايلارغا ئۆزگىچە پارول ئىشلىتىڭ",
    "Unique password …" : "ئۆزگىچە پارول …",
    "Save" : "ساقلا",
    "Change unique password" : "ئۆزگىچە پارولنى ئۆزگەرتىڭ",
    "Failed to save password. Please try again later." : "پارولنى ساقلىيالمىدى. كېيىن قايتا سىناڭ.",
    "Close" : "ياپ",
    "There is no description for this team" : "بۇ كوماندىغا ھېچقانداق چۈشەنچە يوق",
    "Enter a description for the team" : "گۇرۇپپا ئۈچۈن چۈشەندۈرۈش كىرگۈزۈڭ",
    "Folder" : "Folder",
    "Folder name" : "قىسقۇچ ئاتى",
    "Talk conversation" : "پاراڭ سۆھپىتى",
    "New Talk conversation" : "يېڭى پاراڭ سۆھپىتى",
    "Conversation name" : "سۆھبەت ئىسمى",
    "Collective" : "كوللىكتىپ",
    "Calendar" : "كالېندار",
    "New calendar" : "يېڭى يىلنامە",
    "Calendar name" : "كالېندار ئىسمى",
    "Deck board" : "پالۋان تاختىسى",
    "New Deck board" : "يېڭى پالۋان تاختىسى",
    "Board name" : "مۇدىرىيەت ئىسمى",
    "Deck app is not installed. Please install it to create team boards." : "پالۋان ئەپ قاچىلانمىدى. ئەتىرەت مۇدىريىتى قۇرۇش ئۈچۈن ئۇنى قاچىلاڭ.",
    "Unknown resource type" : "نامەلۇم بايلىق تىپى",
    "Team calendar \"{resourceName}\" created and shared with team" : "ئەتىرەت كالىندارى \"{resourceName}\" قۇرۇلدى ھەمدە ئەتىرەت بىلەن ئورتاقلىشىلدى",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" قۇرۇلدى ھەمدە ئەتىرەت بىلەن ئورتاقلىشىلدى",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "\"{name}\" نامدىكى يىلنامە مەۋجۇت. باشقا ئىسىم تاللاڭ.",
    "Failed to create {resourceType}: {error}" : "{resourceType} نى قۇرۇش مەغلۇپ بولدى: {error}",
    "An error happened while saving {fields}" : "{fields} نى ساقلاۋاتقاندا بىر خاتالىق كۆرۈلدى",
    "Team name" : "گۇرۇپپا ئىسمى",
    "Team owner" : "ئەتىرەت باشلىقى",
    "Edit" : "تەھرىر",
    "Request to join" : "قاتنىشىشنى تەلەپ قىلىش",
    "Create" : "قۇر",
    "Show in Calendar" : "كالېنداردا كۆرسەت",
    "Your request to join this team is pending approval" : "بۇ گۇرۇپپىغا قوشۇلۇش تەلىپىڭىز تەستىقلىنىۋاتىدۇ",
    "You are not a member of {circle}" : "سىز {circle} ئەزاسى ئەمەس",
    "Members" : "ئەزالار",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Add more info" : "تېخىمۇ كۆپ ئۇچۇر قوشۇڭ",
    "More fields" : "تېخىمۇ كۆپ ساھە",
    "Please select a valid format" : "ئىناۋەتلىك فورماتنى تاللاڭ",
    "Invalid image" : "ئىناۋەتسىز رەسىم",
    "Error cropping picture" : "كېسىش رەسىمى",
    "Pick an avatar" : "باش سۈرىتىنى تاللاڭ",
    "Pick" : "تاللاڭ",
    "Error while processing the picture." : "رەسىمنى بىر تەرەپ قىلغاندا خاتالىق.",
    "Avatar downloaded from social network" : "ئاۋات ئىجتىمائىي ئالاقە تورىدىن چۈشۈرۈلدى",
    "Avatar already up to date" : "ئاۋاتار ئاللىقاچان يېڭىلانغان",
    "Avatar download failed" : "ئاۋات چۈشۈرۈش مەغلۇب بولدى",
    "Crop contact photo" : "ئالاقىلىشىش سۈرىتى",
    "Upload a new picture" : "يېڭى رەسىم يۈكلەڭ",
    "Choose from Files" : "ھۆججەتلەردىن تاللاڭ",
    "Download picture" : "رەسىم چۈشۈرۈش",
    "Delete picture" : "رەسىمنى ئۆچۈرۈڭ",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "بۇ ئالاقىلىشىش پەقەت ئوقۇش شەكلىدە. بۇ ئالاقىنى تەھرىرلەش ھوقۇقىڭىز يوق.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "سىز تەھرىرلىمەكچى بولغان ئالاقىڭىز ئۆزگەردى. ئالاقىنى قولدا يېڭىلاڭ. باشقا تەھرىرلەشلەر تاشلىۋېتىلىدۇ.",
    "Address book" : "ئادرېس دەپتىرى",
    "Add contact to Birthday Calendar" : "تۇغۇلغان كۈن كالېندارىغا ئالاقىلىشىڭ",
    "Exclude contact from Birthday Calendar" : "تۇغۇلغان كۈن كالېندارىدىكى ئالاقىنى چىقىرىۋېتىڭ",
    "{title} at {organization}" : "{organization} دا {title}",
    "Name" : "ئاتى",
    "Syntax error. Cannot open the contact." : "گرامماتىكىلىق خاتالىق. ئالاقىنى ئاچقىلى بولمايدۇ.",
    "The contact does not exist on the server anymore." : "مۇلازىمېتىردا ئالاقە مەۋجۇت ئەمەس.",
    "Unable to retrieve the contact from the server, please check your network connection." : "مۇلازىمېتىردىن ئالاقىنى ئەسلىگە كەلتۈرەلمەي ، تور ئۇلىنىشىڭىزنى تەكشۈرۈپ بېقىڭ.",
    "An error occurred while trying to move the contact" : "ئالاقىنى يۆتكىمەكچى بولغاندا خاتالىق كۆرۈلدى",
    "An error occurred while trying to copy the contact" : "ئالاقىنى كۆچۈرمەكچى بولغاندا خاتالىق كۆرۈلدى",
    "Unable to update contact" : "ئالاقىنى يېڭىلاشقا ئامالسىز",
    "No contact selected" : "ئالاقىلىشىش تاللانمىدى",
    "Select a contact on the list to begin" : "باشلاش ئۈچۈن تىزىملىكتىكى ئالاقىنى تاللاڭ",
    "Title" : "ماۋزۇ",
    "Company" : "شىركەت",
    "Go to talk conversation" : "پاراڭلىشىشقا بېرىڭ",
    "View profile" : "ئارخىپنى كۆرۈڭ",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "بۇ ئالاقى بۇزۇلۇپ ئوڭشالدى. مەزمۇننى قايتا كۆرۈپ بۇ يەرنى چېكىڭ.",
    "Edit profile" : "ئارخىپنى تەھرىرلەش",
    "Clone contact" : "كلون ئالاقىسى",
    "Generate QR Code" : "QR كودى ھاسىل قىلىڭ",
    "Contact vCard as QR code" : "QC كودى سۈپىتىدە vCard بىلەن ئالاقىلىشىڭ",
    "Pick an address book" : "ئادرېس دەپتىرىنى تاللاڭ",
    "Select address book" : "ئادرېس دەپتىرىنى تاللاڭ",
    "Media shares with you" : "مېدىيا سىز بىلەن ئورتاقلىشىدۇ",
    "Talk conversations with you" : "سىز بىلەن پاراڭلىشىڭ",
    "Calendar events with you" : "كالېندار پائالىيىتى سىز بىلەن",
    "Deck cards with you" : "كارتىڭىزنى سىز بىلەن بىللە",
    "No shared items with this contact" : "بۇ ئالاقىدە ئورتاق بەھرىلىنىدىغان تۈر يوق",
    "This contact cannot be moved" : "بۇ ئالاقىداشنى يۆتكىگىلى بولمايدۇ",
    "This contact cannot be grouped" : "بۇ ئالاقىداشنى گۇرۇپپىلىغىلى بولمايدۇ",
    "Add contacts to groups" : "ئالاقىداشلارنى گۇرۇپپىغا قوش",
    "Move contacts to addressbook" : "ئالاقىداشلارنى ئادرىس دەپتىرىگە يۆتكە",
    "Select groups" : "گۇرۇپپىلارنى تاللا",
    "Select addressbook" : "ئادرېس دەپتىرىنى تاللاڭ",
    "Selected contacts" : "تاللانغان ئالاقىداشلار",
    "Please note that only {count} of the {total} contacts can be added to a group" : "پەقەت {total} دىن {count} ئالاقىداشنى بۇ گۇرۇپپىغا قوشقىلى بولىدىغانلىقىغا دىققەت قىلىڭ",
    "Please note that only {count} of the {total} contacts can be moved" : "پەقەت {total} دىن {count} ئالاقىداشنى يۆتكىگىلى بولىدىغانلىقىغا دىققەت قىلىڭ",
    "Move" : "يۆتكە",
    "from {addressbook}" : "{addressbook} دىن",
    "Confirm merging contacts" : "ئالاقىداشلارنى بىرلەشتۈرۈشنى جەزىملە",
    "The selected contacts have conflicting information. Choose which information to keep" : "تاللانغان ئالاقىلىشىش ئۇچۇرلىرى توقۇنۇشۇۋاتىدۇ. قايسى ئۇچۇرلارنى ساقلاشنى تاللاڭ.",
    "Contacts can be merged" : "ئالاقىداشلارنى بىرلەشتۈرگىلى بولىدۇ",
    "Groups" : "گۇرۇپپىلار",
    "Select groups to add the merged contact to" : "بىرلەشتۈرمەكچى بولغان ئالاقىداشنى قوشىدىغان گۇرۇپپا تاللا",
    "Merge contacts" : "ئالاقىداشلارنى بىرلەشتۈر",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["{number} ئالاقىداشنى ئۆچۈر","{number} ئالاقىداشلارنى ئۆچۈر"],
    "Please select at least one editable contact to delete" : "ئۆچۈرۈش ئۈچۈن كەم دېگەندە بىر ئالاقىداشنى تاللا",
    "Please select two editable contacts to merge" : "بىرلەشتۈرۈش ئۈچۈن ئىككى تەھرىرلىگىلى بولىدىغان ئالاقىداش تاللاڭ",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["{number} ئالاقىداشنى گۇرۇپپىغا قوش","{number} ئالاقىداشنى گۇرۇپپىغا قوش"],
    "Please select at least one editable contact to add to a group" : "گۇرۇپپىغا قوشۇش ئۈچۈن ئەڭ ئاز دىگەندە بىر تەھرىرلىگىلى بولىدىغان ئالاقىداشنى تاللاڭ",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["{number} ئالاقىداشنى ئادرىس دەپتىرىگە يۆتكە","{number} ئالاقىداشنى ئادرىس دەپتىرىگە يۆتكە"],
    "Please select at least one editable contact to move to an addressbook" : "ئادرىس دەپتىرىگە يۆتكەش ئۈچۈن ئەڭ ئاز دىگەندە بىر تەھرىرلىگىلى بولىدىغان ئالاقىداشنى تاللاڭ",
    "Are you sure you want to proceed?" : "داۋاملاشتۇرۇشنى جەزىملەشتۈرەمسىز؟",
    "Add contacts to group" : "ئالاقىداشلارنى گۇرۇپپىغا قوش",
    "Search contacts …" : "ئالاقىداشلارنى ئىزدە ...",
    "Unselect {number}" : "{number} نى تاللىما",
    "Add to {group}" : "{group} قوش",
    "Add members to {group}" : "ئەزالارنى {group} غا قوشۇڭ",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "پەقەت يېزىشقا بولىدىغان ئادرېس دەپتىرىدىكى ئالاقىلىشىشلارنى ئالاقىلىشىش گۇرۇپپىلىرىغا قوشقىلى بولىدىغانلىقىنى ئۇنۇتماڭ. سىستېما ئادرېس دەپتىرى قاتارلىق پەقەت ئوقۇشقا بولىدىغان ئادرېس دەپتىرىدىكى ئالاقىلىشىشلارنى قوشقىلى بولمايدۇ.",
    "Remove {type}" : "{type} نى ئۆچۈر",
    "Add to group" : "گۇرۇپپىغا قوشۇڭ",
    "Add members to group" : "ئەزالارنى گۇرۇپپىغا قوش",
    "Search {types}" : "ئىزدەش {types}",
    "Add guest" : "مىھمان قوش",
    "Search for people to add" : "قوشماقچى بولغان كىشىلەرنى ئىزدەڭ",
    "No results" : "ھېچقانداق نەتىجە يوق",
    "Add {type}" : "{type} نى قوش",
    "New team name" : "يېڭى گۇرۇپپا ئىسمى",
    "Personal team" : "شەخسىي گۇرۇپپا",
    "This team will only be visible to you. Other members will not be able to see or use it." : "بۇ ئەترەت پەقەت سىزنىلا كۆرەلەيدۇ. باشقا ئەزالار ئۇنى كۆرەلمەيدۇ ياكى ئىشلىتەلمەيدۇ.",
    "Local team" : "يەرلىك كوماندا",
    "This team will not be shared with the other instances of the global scale" : "بۇ گۇرۇپپا دۇنيا مىقياسىدىكى باشقا ئەھۋاللار بىلەن ئورتاقلاشمايدۇ",
    "Create team" : "گۇرۇپپا قۇرۇش",
    "Promote as sole owner" : "يەككە ئىگىسى سۈپىتىدە تەشۋىق قىلىڭ",
    "Promote to {level}" : "{level} كۆتۈرۈڭ",
    "Demote to {level}" : "{level} تۆۋەنلىتىش",
    "Are you sure you want to leave this team? This action cannot be undone." : "بۇ گۇرۇپپىدىن راستىنلا ئايرىلماقچىمۇ؟ بۇ ھەرىكەتنى ئەسلىگە كەلتۈرگىلى بولمايدۇ.",
    "Leave team failed." : "ئەتىرەتنى مەغلۇپ بولغان ھالەتتە قوي.",
    "Could not delete the member {displayName}" : "ئەزا {displayName} ئۆچۈرەلمىدى",
    "Could not change the member level to {level}" : "ئەزا دەرىجىسىنى {level} ئۆزگەرتەلمىدى",
    "Could not accept membership request" : "ئەزالىق تەلىپىنى قوبۇل قىلالمىدى",
    "Accept membership request" : "ئەزالىق تەلىپىنى قوبۇل قىلىڭ",
    "Reject membership request" : "ئەزالىق تەلىپىنى رەت قىلىڭ",
    "Manage level" : "سەۋىيەنى باشقۇرۇش",
    "Remove member" : "ئەزا ئۆچۈرۈڭ",
    "Unable to get the results" : "نەتىجىگە ئېرىشەلمىدى",
    "Some members could not be added" : "بەزى ئەزالارنى قوشقىلى بولمىدى",
    "There was an issue adding members to the team" : "كوماندىغا ئەزا قوشۇشتا مەسىلە كۆرۈلدى",
    "Loading members list …" : "ئەزالار تىزىملىكى يۈكلىنىۋاتىدۇ …",
    "The list of members is only visible to members of this team" : "ئەزالار تىزىملىكىنى پەقەت بۇ ئەترەت ئەزالىرىلا كۆرەلەيدۇ",
    "You currently have no access to the member list" : "ھازىر ئەزالار تىزىملىكىنى زىيارەت قىلالمايسىز",
    "Add to {team}" : "{team} غا قوش",
    "Invite members to {team}" : "ئەزالارنى {team} غا تەكلىپ قىل",
    "Pending" : "كۈتۈۋاتىدۇ",
    "Select chart …" : "دىئاگرامما تاللا ...",
    "Chart" : "دىئاگرامما",
    "Select Date" : "چېسلانى تاللاڭ",
    "Select type" : "تىپنى تاللاڭ",
    "Add contact in group" : "گۇرۇپپىغا ئالاقىلىشىڭ",
    "None" : "يوق",
    "Select option" : "تاللاشنى تاللاڭ",
    "Personal dates" : "شەخسىي چېسلالار",
    "Add property of this type" : "بۇ تۈردىكى مۈلۈكنى قوشۇڭ",
    "Member" : "ئەزا",
    "This is a read-only group managed by administrators. Group members can only view this group." : "بۇ پەقەت ئوقۇغىلى بولىدىغان گۇرۇپپا بولۇپ، باشقۇرغۇچىلار تەرىپىدىن باشقۇرۇلىدۇ. گۇرۇپپا ئەزالىرى پەقەت بۇ گۇرۇپپىنىلا كۆرەلەيدۇ.",
    "Unable to create the contact." : "ئالاقىنى قۇرالمىدى.",
    "Contact not found" : "ئالاقىلاشمىدى",
    "Group {group} not found" : "گۇرۇپپا {group} تېپىلمىدى",
    "Add member" : "ئەزا قوشۇڭ",
    "New contact" : "يېڭى ئالاقىلىشىش",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} ئالاقىداشلار {name} غا قوشۇلدى","{success} ئالاقىداشلار {name} غا قوشۇلدى"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} ئالاقىداش {name} غا قوشۇلىدۇ","{success} ئالاقىداش {name} غا قوشۇلىدۇ"],
    "_{count} error_::_{count} errors_" : ["{count} خاتالىق","{count} خاتالىقلار"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n ئالاقىداشلار {addressbook} غا كىرگۈزۈلدى","%n ئالاقىداشلار {addressbook} غا كىرگۈزۈلدى"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n ئالاقىداشلارنى {addressbook} غا كىرگۈزۈش تاماملاندى","%n ئالاقىداشلارنى {addressbook} غا كىرگۈزۈش تاماملاندى"],
    "No data for this contact" : "بۇ ئالاقىداش توغۇرلۇق ئۇچۇر يوق",
    "No data for this contact on their profile" : "بۇ ئالاقىداش توغۇرلۇق ئۇنىڭ تەرجىمالىدا ئۇچۇر يوق",
    "Import" : "ئەكىر",
    "Are you sure you want to import this contact file?" : "بۇ ئالاقىلىشىش ھۆججىتىنى ئەكىرىشنى خالامسىز؟",
    "Could not copy" : "كۆچۈرەلمىدى",
    "Join team" : "كوماندىغا قوشۇلۇڭ",
    "You are about to leave {circle}.\nAre you sure?" : "سىز {circle} دىن ئايرىلماقچى بولۇۋاتىسىز.\nئىشىنەمسىز؟",
    "Please confirm team leave" : "كوماندىنىڭ ئايرىلىشىنى جەزملەشتۈرۈڭ",
    "Could not leave the team {displayName}" : "كوماندىدىن ئايرىلالمىدى {displayName}",
    "Unable to join the team" : "كوماندىغا قوشۇلالمىدى",
    "You are about to delete {circle}.\nAre you sure?" : "سىز {circle} ئۆچۈرمەكچى بولۇۋاتىسىز.\nئىشىنەمسىز؟",
    "Please confirm team deletion" : "گۇرۇپپا ئۆچۈرۈلگەنلىكىنى جەزملەشتۈرۈڭ",
    "Unable to delete the team" : "كوماندىنى ئۆچۈرەلمىدى",
    "Link copied to the clipboard" : "ئۇلىنىش چاپلاش تاختىسىغا كۆچۈرۈلدى",
    "Could not copy link to the clipboard." : "چاپلاش تاختىسىغا ئۇلىنىشنى كۆچۈرەلمىدى.",
    "Not grouped" : "گۇرۇپپا ئەمەس",
    "Organization chart" : "تەشكىلات جەدۋىلى",
    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "گۇرۇپپىلار سىز ئۆزىڭىز قۇرالايدىغان ۋە ئۇلار بىلەن سانلىق مەلۇماتلارنى ئورتاقلىشالايدىغان كىشىلەر توپى. ئۇلار Nextcloud مىسالىدىكى باشقا ھېساباتلار ياكى ھېسابات گۇرۇپپىلىرىدىن تەركىب تاپىدۇ ، شۇنداقلا ئېلېكترونلۇق خەت ئادرېسىڭىزنى كىرگۈزۈش ئارقىلىق ئادرېس دەپتىرىڭىز ياكى ھەتتا سىرتقى كىشىلەر بىلەن ئالاقىلاشسىڭىز بولىدۇ.",
    "Team" : "ئەتىرەت",
    "User" : "ئىشلەتكۈچى",
    "Group" : "گۇرۇپپا",
    "Email" : "تورخەت",
    "Contact" : "ئالاقىلىشىڭ",
    "Moderator" : "رىياسەتچى",
    "Admin" : "باشقۇرغۇچى",
    "Owner" : "ئىگىسى",
    "Invites" : "تەكلىپ قىلىدۇ",
    "Anyone can request membership" : "ھەرقانداق ئادەم ئەزا بولۇشنى تەلەپ قىلسا بولىدۇ",
    "Members need to accept invitation" : "ئەزالار تەكلىپنى قوبۇل قىلىشى كېرەك",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "ئەزالار چوقۇم رىياسەتچى تەرىپىدىن جەزملەشتۈرۈلۈشى ياكى قوبۇل قىلىنىشى كېرەك («ھەرقانداق ئادەم ئەزالىق تەلەپ قىلسا بولىدۇ»)",
    "Members can also invite" : "ئەزالار تەكلىپ قىلسىمۇ بولىدۇ",
    "Membership" : "ئەزالىق",
    "Prevent teams from being a member of another team" : "كوماندىلارنىڭ باشقا كوماندىغا ئەزا بولۇشىنى توسىدۇ",
    "Privacy" : "مەخپىيەتلىك",
    "Visible to everyone" : "ھەممەيلەنگە كۆرگىلى بولىدۇ",
    "users" : "ئىشلەتكۈچى",
    "Users" : "ئىشلەتكۈچى",
    "groups" : "گۇرۇپپىلار",
    "teams" : "گۇرۇپپىلار",
    "email addresses" : "ئېلېكترونلۇق خەت ئادرېسى",
    "Email addresses" : "ئېلخەت ئادرېسى",
    "contacts" : "ئالاقىداشلار",
    "Detailed name" : "تەپسىلىي ئىسمى",
    "Additional names" : "قوشۇمچە ئىسىملار",
    "Prefix" : "ئالدى قوشۇمچە",
    "Suffix" : "ئارقا قوشۇمچە",
    "Nickname" : "تەخەللۇس",
    "Notes" : "ئىزاھاتلار",
    "Website" : "تور بېكەت",
    "Location" : "ئورنى",
    "Federated Cloud ID" : "فېدېراتسىيە بۇلۇت كىملىكى",
    "Home" : "ئۆي",
    "Work" : "ئىش",
    "Other" : "باشقا",
    "Address" : "ئادرېس",
    "Post office box" : "پوچتا ساندۇقى",
    "Extended address" : "كېڭەيتىلگەن ئادرېس",
    "City" : "شەھەر",
    "State or province" : "شىتات ياكى ئۆلكە",
    "Postal code" : "پوچتا نومۇرى",
    "Country" : "دۆلەت",
    "Birthday" : "تۇغۇلغان كۈن",
    "Place of birth" : "تۇغۇلغان جاي",
    "Anniversary" : "يىللىق خاتىرە كۈنى",
    "Date of death" : "ۋاپات بولغان ۋاقىت",
    "Place of death" : "ئۆلۈم ئورنى",
    "Instant messaging" : "تېز ئۇچۇر يوللاش",
    "Phone" : "تېلېفون",
    "Mobile" : "كۆچمە",
    "Work mobile" : "كۆچمە تېلېفون",
    "Home mobile" : "ئۆي يانفۇن",
    "Fax" : "فاكىس",
    "Fax home" : "ئۆي فاكىس",
    "Fax work" : "فاكىس خىزمىتى",
    "Pager" : "چاقىرغۇ",
    "Voice" : "ئاۋاز",
    "Car" : "ماشىنا",
    "Work pager" : "خىزمەت قەغىزى",
    "Line manager" : "لىنىيە باشقۇرغۇچى",
    "Social network" : "ئىجتىمائىي ئالاقە تورى",
    "Relationship to you" : "سىز بىلەن بولغان مۇناسىۋەت",
    "Spouse" : "جورىسى",
    "Child" : "بالا",
    "Mother" : "ئانا",
    "Father" : "ئاتا",
    "Parent" : "ئاتا-ئانا",
    "Brother" : "بۇرادەر",
    "Sister" : "سىڭلىم",
    "Relative" : "نىسپىي",
    "Friend" : "دوست",
    "Colleague" : "خىزمەتداش",
    "Assistant" : "ياردەمچى",
    "Related contacts" : "مۇناسىۋەتلىك ئالاقىداشلار",
    "Agent" : "ۋاكالەتچى",
    "Emergency" : "جىددى ئەھۋال",
    "Co-worker" : "خىزمەتدىشى",
    "Gender" : "جىنىس",
    "Female" : "ئايال",
    "Male" : "ئەر",
    "Unknown" : "نامەلۇم",
    "Time zone" : "ۋاقىت رايونى",
    "Spoken languages" : "سۆزلەنگەن تىللار",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} ئالاقىداشنى ئوقۇش مەغلۇپ بولدى","{failed} ئالاقىداشنى ئوقۇش مەغلۇپ بولدى"],
    "An error has occurred in team(s). Check the console for more details." : "گۇرۇپپا (لار) دا خاتالىق كۆرۈلدى. تېخىمۇ كۆپ تەپسىلاتلارنى كونترول سۇپىسىدىن تەكشۈرۈڭ.",
    "Unable to create team {circleName}" : "گۇرۇپپا {circleName} create قۇرالمىدى",
    "Unable to delete team {circleId}" : "گۇرۇپپا {circleId} ئۆچۈرگىلى بولمىدى",
    "Unable to delete contact" : "ئالاقىنى ئۆچۈرەلمىدى"
},
"nplurals=2; plural=(n != 1);");
