OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importuoti adresatus",
    "Details" : "Išsamiau",
    "All contacts" : "Visi adresatai",
    "Contacts" : "Adresatai",
    "A contacts app for Nextcloud" : "Adresatų programėlė, skirta Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud adresatų programėlė yra Nextcloud CardDAV serverio naudotojo sąsaja. Naudodami savo Nextcloud, lengvai sinchronizuokite adresatus iš įvairių įrenginių ir taisykite juos internete.\n\n* 🚀 **Integracija su kitomis Nextcloud programėlėmis!** Šiuo metu su Paštu ir Kalendoriumi – greitu laiku ir su kitomis.\n* 🎉 **Niekada nepamirškite apie gimtadienį!** Galite sinchronizuoti gimtadienius ir kitus pasikartojančius įvykius naudodami savo Nextcloud Kalendorių.\n* 👥 **Adresų knygų bendrinimas!** Norite bendrinti adresatus su savo draugais ar kolegomis? Jokių problemų!\n* 🙈 **Mes neišradinėjame dviračio!** Pagrįsta puikia ir atvira SabreDAV biblioteka.",
    "Copy to full name" : "Kopijuoti į vardą, pavardę",
    "Omit year" : "Neįtraukti metų",
    "Allow updating avatars from social media" : "Leisti atnaujinti avatarus iš socialinių tinklų",
    "There was an error fetching the member list" : "Gaunant narių sąrašą įvyko klaida",
    "Please select a team" : "Pasirinkite komandą",
    "Loading team…" : "Įkeliama komanda…",
    "There are no contacts yet" : "Kol kas nėra adresatų",
    "Create contact" : "Sukurti adresatą",
    "There are no contacts in this group" : "Šioje grupėje nėra adresatų",
    "Create contacts" : "Sukurti adresatus",
    "Add contacts" : "Pridėti adresatus",
    "Manage team" : "Tvarkyti komandą",
    "Leave team" : "Išeiti iš komandos",
    "Delete team" : "Ištrinti komandą",
    "Contacts settings" : "Adresatų nustatymai",
    "Update avatars from social media" : "Atnaujinti avatarus iš socialinių tinklų",
    "Address books" : "Adresų knygos",
    "Rename" : "Pervadinti",
    "Export" : "Eksportuoti",
    "Send email" : "Siųsti elektroninį laišką",
    "Delete" : "Ištrinti",
    "Show all groups" : "Rodyti visas grupes",
    "Collapse groups" : "Suskleisti grupes",
    "Show all teams" : "Rodyti visas komandas",
    "Collapse teams" : "Suskleisti komandas",
    "Group name cannot be empty" : "Grupės pavadinimas negali būti tuščias",
    "This group already exists" : "Ši grupė jau yra",
    "An error occurred while creating the group" : "Kuriant grupę įvyko klaida",
    "This team already exists" : "Ši komanda jau yra",
    "An error happened during the creation of the team" : "Komandos kūrimo metu įvyko klaida",
    "Recently contacted" : "Paskiausiai susisiekta",
    "Contact groups" : "Adresatų grupės",
    "Create a new contact group" : "Sukurti naują adresatų grupę",
    "Contact group name" : "Adresatų grupės pavadinimas",
    "Teams" : "Komandos",
    "Create a new team" : "Sukurti naują komandą",
    "Open the contacts app settings" : "Atverti adresatų programėlės nustatymus",
    "Copied" : "Nukopijuota",
    "Cannot copy" : "Nepavyksta nukopijuoti",
    "Copy link" : "Kopijuoti nuorodą",
    "Toggling of address book was not successful" : "Adresų knygos perjungimas buvo nesėkmingas",
    "This will delete the address book and every contacts within it" : "Tai ištrins adresų knygą ir visus joje esančius adresatus",
    "Delete {addressbook}?" : "Ištrinti {addressbook}?",
    "Unshare {addressbook}?" : "Nustoti bendrinti {addressbook}?",
    "Deletion of address book was not successful." : "Adresų knygos ištrynimas buvo nesėkmingas",
    "Renaming of address book was not successful." : "Adresų knygos pervadinimas buvo nesėkmingas",
    "Download" : "Atsisiųsti",
    "Show" : "Rodyti",
    "_%n contact_::_%n contacts_" : ["%n adresatas","%n adresatai","%n adresatų","%n adresatas"],
    "_%n group_::_%n groups_" : ["%n grupė","%n grupės","%n grupių","%n grupė"],
    "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
    "Share with users" : "Bendrinti su naudotojais",
    "No users or groups" : "Nėra jokių naudotojų ar grupių",
    "Unable to delete the share" : "Nepavyko ištrinti viešinio",
    "Unable to change permissions" : "Nepavyko pakeisti leidimų",
    "Choose a vCard file to import" : "Pasirinkite norimą importuoti vCard failą",
    "Import into the {addressbookName} address book" : "Importuoti į {addressbookName} adresų knygą",
    "Select local file" : "Pasirinkti vietinį failą",
    "Import from files" : "Importuoti iš failų",
    "Importing is disabled because there are no address books available" : "Importavimas yra išjungtas, nes nėra prieinamų adresų knygų",
    "An error occurred, unable to create the address book" : "Įvyko klaida, nepavyko sukurti adresų knygos",
    "Add new address book" : "Pridėti naują adresų knygą",
    "Cancel" : "Atsisakyti",
    "Add" : "Add",
    "First name" : "Vardas",
    "Last name" : "Pavardė",
    "Phonetic first name" : "Fonetinis vardas",
    "Phonetic last name" : "Fonetinė pavardė",
    "Display name" : "Rodomas vardas",
    "Last modified" : "Paskutinis modifikavimas",
    "Manages" : "Tvarko",
    "Oversees" : "Prižiūri",
    "An error happened during the config change" : "Keičiant konfigūraciją įvyko klaida",
    "Save" : "Įrašyti",
    "Failed to save password. Please try again later." : "Nepavyko įrašyti slaptažodžio. Vėliau bandykite dar kartą.",
    "Close" : "Užverti",
    "There is no description for this team" : "Ši komanda neturi aprašo",
    "Enter a description for the team" : "Įveskite komandos aprašą",
    "Folder" : "Folder",
    "Team name" : "Komandos pavadinimas",
    "Edit" : "Taisyt",
    "Request to join" : "Prašyti prisijungti",
    "Create" : "Sukurti",
    "Your request to join this team is pending approval" : "Jūsų užklausa prisijungti prie šios komandos laukia patvirtinimo",
    "You are not a member of {circle}" : "Jūs nesate rato {circle} narys",
    "Members" : "Nariai",
    "Confirm" : "Patvirtinti",
    "Add more info" : "Pridėti daugiau informacijos",
    "More fields" : "Daugiau laukų",
    "Please select a valid format" : "Pasirinkite tinkamą formatą",
    "Invalid image" : "Netinkamas paveikslas",
    "Error cropping picture" : "Klaida apkerpant nuotrauką",
    "Pick an avatar" : "Pasirinkite avatarą",
    "Error while processing the picture." : "Klaida apdorojant paveikslėlį.",
    "Avatar downloaded from social network" : "Avataras atsiųstas iš socialinio tinklo",
    "Avatar already up to date" : "Avataras jau yra naujausias",
    "Avatar download failed" : "Avataro atsiuntimas nepavyko",
    "Crop contact photo" : "Apkirpti adresato nuotrauką",
    "Upload a new picture" : "Įkelti naują paveikslą",
    "Choose from Files" : "Pasirinkti iš failų",
    "Download picture" : "Atsisiųsti paveikslėlį",
    "Delete picture" : "Ištrinti paveikslėlį",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šis adresatas yra tik skaitymo veiksenoje. Jūs neturite leidimo taisyti šį adresatą.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Adresatas, kurį bandote taisyti, pasikeitė. Įkelkite rankiniu būdu adresatą iš naujo. Bet kokie tolimesni taisymai bus atmesti.",
    "Address book" : "Adresatų knyga",
    "{title} at {organization}" : "{title} iš {organization}",
    "Name" : "Vardas",
    "Syntax error. Cannot open the contact." : "Sintaksės klaida. Nepavyko atverti adresato.",
    "The contact does not exist on the server anymore." : "Adresato šiame serveryje daugiau nebėra.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nepavyko gauti adresato iš serverio, patikrinkite savo tinklo ryšį.",
    "An error occurred while trying to move the contact" : "Bandant perkelti adresatą, įvyko klaida",
    "An error occurred while trying to copy the contact" : "Bandant nukopijuoti adresatą, įvyko klaida",
    "Unable to update contact" : "Nepavyko atnaujinti adresato",
    "No contact selected" : "Nepasirinktas joks adresatas",
    "Select a contact on the list to begin" : "Norėdami pradėti, pasirinkite adresatą iš sąrašo",
    "Title" : "Pareigos",
    "Company" : "Kompanija",
    "View profile" : "Rodyti profilį",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Šis adresatas buvo sugadintas ir pataisytas. Peržiūrėkite turinį ir spustelėkite čia, norėdami adresatą įrašyti.",
    "Edit profile" : "Taisyti profilį",
    "Clone contact" : "Dubliuoti adresatą",
    "Generate QR Code" : "Generuoti QR kodą",
    "Contact vCard as QR code" : "Adresato vCard kaip QR kodas",
    "Pick an address book" : "Pasirinkti adresų knygą",
    "Select address book" : "Pasirinkti adresų knygą",
    "Move" : "Move",
    "Add to {group}" : "Pridėti į {group}",
    "Remove {type}" : "Šalinti {type}",
    "Add to group" : "Pridėti į grupę",
    "Search {types}" : "Ieškoti {types}",
    "Search for people to add" : "Ieškoti norimų pridėti žmonių",
    "No results" : "Rezultatų nėra",
    "Add {type}" : "Pridėti {type}",
    "New team name" : "Naujas komandos pavadinimas",
    "Personal team" : "Asmeninė komanda",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Ši komanda bus matoma tik jums. Kiti nariai negalės jos matyti ar ja naudotis.",
    "Local team" : "Vietinė komanda",
    "Create team" : "Sukurti komandą",
    "Promote to {level}" : "Paaukštinti į {level}",
    "Demote to {level}" : "Pažeminti iki {level}",
    "Accept membership request" : "Priimti narystės užklausą",
    "Reject membership request" : "Atmesti narystės užklausą",
    "Remove member" : "Šalinti narį",
    "Unable to get the results" : "Nepavyko gauti rezultatų",
    "Some members could not be added" : "Kai kurių narių nepavyko pridėti",
    "The list of members is only visible to members of this team" : "Narių sąrašas yra matomas tik šios komandos nariams",
    "You currently have no access to the member list" : "Jūs šiuo metu neturite prieigos prie narių sąrašo",
    "Pending" : "Laukiantis",
    "Select Date" : "Pasirinkti datą",
    "Select type" : "Pasirinkite tipą",
    "Add contact in group" : "Pridėti adresatą į grupę",
    "None" : "Nėra",
    "Select option" : "Pasirinkite parinktį",
    "Member" : "Narys",
    "Unable to create the contact." : "Nepavyko sukurti adresato.",
    "Contact not found" : "Adresatas nerastas",
    "Group {group} not found" : "Grupė {group} nerasta",
    "Add member" : "Pridėti narį",
    "New contact" : "Naujas adresatas",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} adresatas sėkmingai pridėtas į {name}","{success} adresatai sėkmingai pridėti į {name}","{success} adresatų sėkmingai pridėta į {name}","{success} adresatas sėkmingai pridėtas į {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Pridedamas {success} adresatas į {name}","Pridedami {success} adresatai į {name}","Pridedama {success} adresatų į {name}","Pridedamas {success} adresatas į {name}"],
    "_{count} error_::_{count} errors_" : ["{count} klaida","{count} klaidos","{count} klaidų","{count} klaida"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n adresatas importuojamas į {addressbook}","%n adresatai importuojami į {addressbook}","%n adresatų importuojama į {addressbook}","%n adresatas importuojamas į {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Atliktas %n adresato importavimas į {addressbook}","Atliktas %n adresatų importavimas į {addressbook}","Atliktas %n adresatų importavimas į {addressbook}","Atliktas %n adresato importavimas į {addressbook}"],
    "Import" : "Importuoti",
    "Are you sure you want to import this contact file?" : "Ar tikrai norite importuoti šį adresato failą?",
    "Could not copy" : "Nepavyko nukopijuoti",
    "Join team" : "Prisijungti prie komandos",
    "You are about to leave {circle}.\nAre you sure?" : "Jūs ketinate išeiti iš {circle}.\nAr esate tikri?",
    "Please confirm team leave" : "Patvirtinkite išėjimą iš komandos",
    "Could not leave the team {displayName}" : "Nepavyko išeiti iš komandos {displayName}",
    "Unable to join the team" : "Nepavyko prisijungti prie komandos",
    "You are about to delete {circle}.\nAre you sure?" : "Jūs ketinate ištrinti {circle}.\nAr esate tikri?",
    "Please confirm team deletion" : "Patvirtinkite komandos ištrynimą",
    "Unable to delete the team" : "Nepavyko ištrinti komandos",
    "Link copied to the clipboard" : "Nuoroda nukopijuota į iškarpinę",
    "Could not copy link to the clipboard." : "Nepavyko nukopijuoti nuorodos į iškarpinę.",
    "Not grouped" : "Nesugrupuoti",
    "Team" : "Komanda",
    "User" : "Naudotojas",
    "Group" : "Grupė",
    "Email" : "El. paštas",
    "Contact" : "Adresatas",
    "Moderator" : "Moderatorius",
    "Admin" : "Administratorius",
    "Owner" : "Savininkas",
    "Invites" : "Pakvietimai",
    "Prevent teams from being a member of another team" : "Neleisti komandoms būti kitos komandos nariu",
    "Visible to everyone" : "Matomas visiems",
    "users" : "naudotojai",
    "Users" : "Naudotojai",
    "groups" : "grupės",
    "teams" : "komandos",
    "email addresses" : "el. pašto adresai",
    "Email addresses" : "El. pašto adresai",
    "Detailed name" : "Išsamus vardas",
    "Additional names" : "Papildomi vardai",
    "Prefix" : "Priešvardis",
    "Suffix" : "Povardis",
    "Nickname" : "Slapyvardis",
    "Notes" : "Pastabos",
    "Website" : "Svetainė",
    "Location" : "Vieta",
    "Federated Cloud ID" : "Federacinės debesijos ID",
    "Home" : "Namų",
    "Work" : "Darbo",
    "Other" : "Kita",
    "Address" : "Adresas",
    "Post office box" : "Pašto dėžutė",
    "Extended address" : "Išplėstinis adresas",
    "City" : "Miestas",
    "State or province" : "Regionas ar apskritis",
    "Postal code" : "Pašto kodas",
    "Country" : "Šalis",
    "Birthday" : "Gimtadienis",
    "Place of birth" : "Gimimo vieta",
    "Anniversary" : "Metinės",
    "Date of death" : "Mirties data",
    "Place of death" : "Mirties vieta",
    "Instant messaging" : "Pokalbių programa",
    "Phone" : "Telefonas",
    "Mobile" : "Mobilusis",
    "Work mobile" : "Darbo mobilusis",
    "Home mobile" : "Namų mobilusis",
    "Fax" : "Faksas",
    "Fax home" : "Namų faksas",
    "Fax work" : "Darbo faksas",
    "Pager" : "Pranešimų gaviklis",
    "Voice" : "Balso pašto",
    "Car" : "Automobilis",
    "Work pager" : "Darbo pranešimų gaviklis",
    "Social network" : "Socialinis tinklas",
    "Relationship to you" : "Ryšys su jumis",
    "Spouse" : "Sutuoktinis",
    "Child" : "Vaikas",
    "Mother" : "Mama",
    "Father" : "Tėtis",
    "Parent" : "Tėvai",
    "Brother" : "Brolis",
    "Sister" : "Sesuo",
    "Relative" : "Giminaitis",
    "Friend" : "Draugas",
    "Colleague" : "Bendradarbis",
    "Assistant" : "Asistentas",
    "Related contacts" : "Susiję adresatai",
    "Agent" : "Agentas",
    "Emergency" : "Skubus atvejis",
    "Co-worker" : "Bendradarbis",
    "Gender" : "Lytis",
    "Female" : "Moteris",
    "Male" : "Vyras",
    "Unknown" : "Nežinoma",
    "Time zone" : "Laiko juosta",
    "Spoken languages" : "Šnekamosios kalbos",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Nepavyko perskaityti {failed} adresato","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresato"],
    "Unable to create team {circleName}" : "Nepavyko sukurti komandos {circleName}",
    "Unable to delete team {circleId}" : "Nepavyko ištrinti komandos {circleId}",
    "Unable to delete contact" : "Nepavyko ištrinti adresato"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
