OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importar contatos",
    "Details" : "Detalhes",
    "All contacts" : "Todos os contatos",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n contato importado","%n de contatos importados","%n contatos importados"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n contato ignorado)","(%n de contatos ignorados)","(%n contatos ignorados)"],
    "Contacts" : "Contatos",
    "A contacts app for Nextcloud" : "Um aplicativo de contatos para Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "O aplicativo Nextcloud Contatos é uma interface de usuário para o servidor CardDAV do Nextcloud. Sincronize facilmente os contatos em vários dispositivos e edite-os on-line.\n\n* 🚀 **Integração com outros aplicativos Nextcloud!** Atualmente, E-mail e Calendário – mais por vir.\n* 🎉 **Nunca esqueça um aniversário!** Você pode sincronizar aniversários e outros eventos recorrentes com o seu Calendário do Nextcloud.\n* 👥 **Compartilhamento de Catálogo de Endereços!** Você quer compartilhar seus contatos com seus amigos ou colegas de trabalho? Tranquilo!\n* 🙈 **Não estamos reinventando a roda!** Com base na grande e aberta biblioteca SabreDAV.",
    "Copy to full name" : "Copiar para o nome completo",
    "Omit year" : "Omitir ano",
    "Allow updating avatars from social media" : "Permitir atualização de avatares das mídias sociais",
    "There was an error fetching the member list" : "Ocorreu um erro ao obter a lista de membros",
    "Please select a team" : "Por favor, selecione uma equipe",
    "Loading team…" : "Carregando equipe…",
    "Loading contacts …" : "Carregando contatos …",
    "There are no contacts yet" : "Ainda não há contatos",
    "Create contact" : "Criar contato",
    "There are no contacts in this group" : "Não há contatos neste grupo",
    "Create contacts" : "Criar contatos",
    "Add contacts" : "Adicionar contatos",
    "Loading …" : "Carregando …",
    "Manage team" : "Gerenciar equipe",
    "Leave team" : "Sair da equipe",
    "Delete team" : "Excluir equipe",
    "Setting saved" : "Configuração salva",
    "Failed to save setting" : "Falha ao salvar a configuração",
    "Contacts settings" : "Configurações de Contatos",
    "General" : "Geral",
    "Update avatars from social media" : "Atualizar avatares pela mídia social",
    "Refreshed once per week" : "Atualizado uma vez por semana",
    "Address books" : "Catálogos de endereços",
    "Tried to drop an invalid contact!" : "Tentou excluir um contato inválido!",
    "Rename" : "Renomear",
    "Export" : "Exportar",
    "Send email" : "Enviar e-mail",
    "Send email as BCC" : "Enviar e-mail como CCO",
    "Delete" : "Excluir",
    "Show all groups" : "Mostrar todos os grupos",
    "Collapse groups" : "Recolher grupos",
    "Show all teams" : "Mostrar todas as equipes",
    "Collapse teams" : "Recolher equipes",
    "Group name cannot be empty" : "Nome do grupo não pode ser vazio",
    "This group already exists" : "Este grupo já existe",
    "An error occurred while creating the group" : "Ocorreu um erro ao criar o grupo",
    "This team already exists" : "Essa equipe já existe",
    "An error happened during the creation of the team" : "Ocorreu um erro durante a criação da equipe",
    "Recently contacted" : "Contactados recentemente",
    "Contact groups" : "Grupos de contatos",
    "Create a new contact group" : "Criar um novo grupo de contatos",
    "Contact group name" : "Nome do grupo de contatos",
    "Teams" : "Equipes",
    "Create a new team" : "Criar uma nova equipe",
    "Open the contacts app settings" : "Abrir as configurações do aplicativo Contatos",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartilhado com {num} entidade","Compartilhado com {num} entidades","Compartilhado com {num} entidades"],
    "Copied" : "Copiado",
    "Cannot copy" : "Não pode copiar ",
    "Copy link" : "Copiar link",
    "Toggling of address book was not successful" : "A alternância do catálogo de endereços não foi bem-sucedida",
    "This will delete the address book and every contacts within it" : "Isso excluirá o catálogo de endereços e todos os contatos nele",
    "Delete {addressbook}?" : "Excluir {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Isso descompartilhará o catálogo de endereços e de todos os contatos nele",
    "Unshare {addressbook}?" : "Descompartilhar {addressbook}?",
    "Deletion of address book was not successful." : "A exclusão do catálogo de endereços não foi bem-sucedida.",
    "Renaming of address book was not successful." : "A renomeação do catálogo de endereços não foi bem-sucedida.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Oculto)",
    "Download" : "Baixar",
    "Show" : "Mostrar",
    "Unshare from me" : "Descompartilhar de mim",
    "_%n contact_::_%n contacts_" : ["%n contato","%n contatos","%n contatos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos","%n grupos"],
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "Share with users" : "Compartilhar com usuários",
    "No users or groups" : "Nenhum usuário ou grupo",
    "Unable to delete the share" : "Não foi possível excluir o compartilhamento",
    "Unable to change permissions" : "Não é possível alterar as permissões",
    "can create and edit" : "pode criar e editar",
    "Choose a vCard file to import" : "Escolha um arquivo vCard para importar",
    "Import into the {addressbookName} address book" : "Importar para o catálogo de endereços  {addressbookName}",
    "Select local file" : "Selecionar um arquivo local",
    "Import from files" : "Importar de Arquivos",
    "Importing is disabled because there are no address books available" : "A importação está desativada porque não há catálogos de endereços disponíveis",
    "An error occurred, unable to create the address book" : "Ocorreu um erro ao criar o catálogo de endereços",
    "New address book" : "Novo catálogo de endereços",
    "Add new address book" : "Adicionar novo catálogo de endereços",
    "Cancel" : "Cancelar",
    "Add" : "Adicionar",
    "First name" : "Primeiro nome",
    "Last name" : "Sobrenome",
    "Phonetic first name" : "Primeiro nome fonético",
    "Phonetic last name" : "Último nome fonético",
    "Display name" : "Nome de exibição",
    "Last modified" : "Última modificação",
    "Sort contacts by" : "Ordenar contatos por",
    "Manages" : "Gerencia",
    "Oversees" : "Supervisiona",
    "An error happened during the config change" : "Ocorreu um erro durante a mudança das configurações",
    "Enforce password protection on files shared to this team" : "Impor proteção por senha aos arquivos compartilhados com esta equipe",
    "Use a unique password for all shares to this team" : "Usar uma senha única para todos os compartilhamentos desta equipe",
    "Unique password …" : "Senha única …",
    "Save" : "Salvar",
    "Change unique password" : "Alterar senha única",
    "Failed to save password. Please try again later." : "Falha ao salvar a senha. Por favor, tente novamente mais tarde.",
    "Close" : "Fechar",
    "There is no description for this team" : "Não há descrição para esta equipe",
    "Enter a description for the team" : "Insira uma descrição para a equipe",
    "Folder" : "Pasta",
    "New folder" : "Nova pasta",
    "Folder name" : "Nome da pasta",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Isso criará uma pasta comum compartilhada com a equipe. Para criar uma pasta da equipe, entre em contato com a administração do {productName}.",
    "Talk conversation" : "Conversa Talk",
    "New Talk conversation" : "Nova conversa do Talk",
    "Conversation name" : "Nome da conversa",
    "Collective" : "Coletivo",
    "Calendar" : "Calendário",
    "New calendar" : "Novo calendário",
    "Calendar name" : "Nome do calendário",
    "Deck board" : "Painel de Deck",
    "New Deck board" : "Novo painel de Deck",
    "Board name" : "Nome do painel",
    "Deck app is not installed. Please install it to create team boards." : "O aplicativo Deck não está instalado. Por favor, instale-o para criar painéis de equipe.",
    "Unknown resource type" : "Tipo de recurso desconhecido",
    "Team calendar \"{resourceName}\" created and shared with team" : "Calendário de equipe \"{resourceName}\" criado e compartilhado com a equipe",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" criado e compartilhado com a equipe",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Já existe um calendário chamado \"{name}\". Escolha um nome diferente.",
    "Failed to create {resourceType}: {error}" : "Falha ao criar {resourceType}: {error}",
    "An error happened while saving {fields}" : "Ocorreu um erro ao salvar {fields}",
    "Team name" : "Nome da equipe",
    "Team owner" : "Proprietário da equipe",
    "Edit" : "Editar",
    "Request to join" : "Solicitar adesão",
    "Create" : "Criar",
    "Show in Calendar" : "Mostrar no Calendário",
    "Your request to join this team is pending approval" : "Seu pedido de adesão a esta equipe está pendente de aprovação",
    "You are not a member of {circle}" : "Você não é membro de {circle}",
    "Members" : "Membros",
    "Confirm" : "Confirmar",
    "Add more info" : "Adicionar mais informações",
    "More fields" : "Mais campos",
    "Please select a valid format" : "Selecione um formato válido",
    "Invalid image" : "Imagem inválida",
    "Error cropping picture" : "Erro ao recortar imagem",
    "Pick an avatar" : "Escolha um avatar",
    "Pick" : "Escolha",
    "Error while processing the picture." : "Erro ao processar a imagem.",
    "Avatar downloaded from social network" : "Avatar baixado da rede social",
    "Avatar already up to date" : "Avatar já atualizado",
    "Avatar download failed" : "Falha no download do avatar",
    "Crop contact photo" : "Cortar foto do contato",
    "Upload a new picture" : "Enviar uma nova imagem",
    "Choose from Files" : "Escolher de Arquivos",
    "Download picture" : "Baixar imagem",
    "Delete picture" : "Excluir imagem",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contato é somente leitura. Você não tem permissão para editar este contato.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "O contato que você estava tentando editar foi alterado. Atualize manualmente o contato. Qualquer outra edição será descartada.",
    "Address book" : "Catálogo de endereços",
    "Add contact to Birthday Calendar" : "Adicionar contato ao Calendário de Aniversários",
    "Exclude contact from Birthday Calendar" : "Excluir contato do Calendário de Aniversários",
    "{title} at {organization}" : "{title} em {organization}",
    "Name" : "Nome",
    "Syntax error. Cannot open the contact." : "Erro de sintaxe. Não é possível abrir o contato.",
    "The contact does not exist on the server anymore." : "O contato não existe mais no servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Não foi possível recuperar o contato do servidor, verifique sua conexão de rede.",
    "An error occurred while trying to move the contact" : "Ocorreu um erro ao mover o contato",
    "An error occurred while trying to copy the contact" : "Ocorreu um erro ao copiar o contato",
    "Unable to update contact" : "Não foi possível atualizar o contato",
    "No contact selected" : "Nenhum contato selecionado",
    "Select a contact on the list to begin" : "Selecione um contato na lista para começar",
    "Title" : "Título",
    "Company" : "Empresa",
    "Go to talk conversation" : "Ir para conversa do Talk",
    "View profile" : "Ver perfil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contato foi corrompido e recebeu uma correção. Revise o conteúdo e clique aqui para salvá-lo.",
    "Edit profile" : "Editar perfil",
    "Clone contact" : "Clonar contato",
    "Generate QR Code" : "Gerar Código QR",
    "Contact vCard as QR code" : "vCard do contato como código QR",
    "Pick an address book" : "Escolha um catálogo de endereços",
    "Select address book" : "Selecione o catálogo de endereços",
    "Media shares with you" : "Compartilhamentos de mídia com você",
    "Talk conversations with you" : "Conversas do Talk com você",
    "Calendar events with you" : "Eventos de calendário com você",
    "Deck cards with you" : "Cartões de Deck com você",
    "No shared items with this contact" : "Nenhum item compartilhado com este contato",
    "This contact cannot be moved" : "Este contato não pode ser movido",
    "This contact cannot be grouped" : "Este contato não pode ser agrupado",
    "Add contacts to groups" : "Adicionar contatos a grupos",
    "Move contacts to addressbook" : "Mover contatos para o catálogo de endereços",
    "Select groups" : "Selecionar grupos",
    "Select addressbook" : "Selecionar catálogo de endereços",
    "Selected contacts" : "Contatos selecionados",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Observe que apenas {count} dos {total} contatos podem ser adicionados a um grupo",
    "Please note that only {count} of the {total} contacts can be moved" : "Observe que apenas {count} dos {total} contatos podem ser movidos",
    "Move" : "Mover",
    "from {addressbook}" : "de {addressbook}",
    "Confirm merging contacts" : "Confirmar a fusão de contatos",
    "The selected contacts have conflicting information. Choose which information to keep" : "Os contatos selecionados têm informações conflitantes. Escolha quais informações deseja manter.",
    "Contacts can be merged" : "Os contatos podem ser mesclados",
    "Groups" : "Grupos",
    "Select groups to add the merged contact to" : "Selecione os grupos aos quais deseja adicionar o contato mesclado",
    "Merge contacts" : "Mesclar contatos",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Excluir {number} contato","Excluir {number} de contatos","Excluir {number} contatos"],
    "Please select at least one editable contact to delete" : "Selecione pelo menos um contato editável para excluir",
    "Please select two editable contacts to merge" : "Por favor, selecione dois contatos editáveis para mesclar",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Adicionar {number} contato ao grupo","Adicionar {number} de contatos ao grupo","Adicionar {number} contatos ao grupo"],
    "Please select at least one editable contact to add to a group" : "Selecione pelo menos um contato editável para adicionar a um grupo",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Mover {number} contato para o catálogo de endereços","Mover {number} de contatos para o catálogo de endereços","Mover {number} contatos para o catálogo de endereços"],
    "Please select at least one editable contact to move to an addressbook" : "Selecione pelo menos um contato editável para mover para um catálogo de endereços",
    "Are you sure you want to proceed?" : "Tem certeza de que deseja continuar?",
    "Add contacts to group" : "Adicionar contatos ao grupo",
    "Search contacts …" : "Pesquisando contatos …",
    "Unselect {number}" : "Desselecionar {number}",
    "Add to {group}" : "Adicionar a {group}",
    "Add members to {group}" : "Adicionar membros a {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Observe que só é possível adicionar contatos de catálogos de endereços graváveis a grupos de contatos. Os contatos de catálogos de endereços somente leitura, como o catálogo de endereços do sistema, não podem ser adicionados.",
    "Remove {type}" : "Excluir {type}",
    "Add to group" : "Adicionar ao grupo",
    "Add members to group" : "Adicionar membros ao grupo",
    "Search {types}" : "Pesquisar {types}",
    "Add guest" : "Adicionar convidado",
    "Search for people to add" : "Pesquisar pessoas para adicionar",
    "No results" : "Sem resultados",
    "Add {type}" : "Adicionar {type}",
    "New team name" : "Nome da nova equipe",
    "Personal team" : "Equipe pessoal",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Esta equipe ficará visível apenas para você. Outros membros não poderão vê-lo ou usá-lo.",
    "Local team" : "Equipe local",
    "This team will not be shared with the other instances of the global scale" : "Esta equipe não será compartilhada com as outras instâncias da escala global",
    "Create team" : "Criar equipe",
    "Promote as sole owner" : "Promover como único proprietário",
    "Promote to {level}" : "Promover para {level}",
    "Demote to {level}" : "Rebaixar para {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Tem certeza de que deseja deixar esta equipe? Esta ação não pode ser desfeita.",
    "Leave team failed." : "Falha na saída da equipe.",
    "Could not delete the member {displayName}" : "Não foi possível excluir o membro {displayName}",
    "Could not change the member level to {level}" : "Não foi possível alterar o nível de membro para {level}",
    "Could not accept membership request" : "Não foi possível aceitar o pedido de adesão ",
    "Accept membership request" : "Aceitar o pedido de adesão",
    "Reject membership request" : "Rejeitar o pedido de adesão",
    "Manage level" : "Gerenciar nível",
    "Remove member" : "Remover membro",
    "Unable to get the results" : "Não é possível obter os resultados",
    "Some members could not be added" : "Alguns membros não puderam ser adicionados",
    "There was an issue adding members to the team" : "Ocorreu um problema ao adicionar membros à equipe",
    "Loading members list …" : "Carregando lista de membros …",
    "The list of members is only visible to members of this team" : "A lista de membros só é visível para membros desta equipe",
    "You currently have no access to the member list" : "No momento, você não tem acesso à lista de membros",
    "Add to {team}" : "Adicionar a {team}",
    "Invite members to {team}" : "Convidar membros para {team}",
    "Pending" : "Pendente",
    "Select chart …" : "Selecione um gráfico …",
    "Chart" : "Gráfico",
    "Select Date" : "Selecionar Data",
    "Select type" : "Selecionar tipo",
    "Add contact in group" : "Adicionar contato ao grupo",
    "None" : "Nenhum",
    "copy" : "copiar",
    "Select option" : "Selecionar a opção",
    "note" : "nota",
    "email" : "e-mail",
    "send an email" : "enviar um e-mail",
    "Personal dates" : "Datas pessoais",
    "Add property of this type" : "Adicionar propriedade deste tipo",
    "Member" : "Membro",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Este é um grupo somente leitura gerenciado por administradores. Os membros do grupo só podem visualizar este grupo.",
    "Unable to create the contact." : "Não foi possível criar o contato.",
    "Contact not found" : "Contato não encontrado",
    "Group {group} not found" : "Grupo {group} não encontrado",
    "Add member" : "Adicionar membro",
    "New contact" : "Novo contato",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contato adicionado a {name}","{success} contatos adicionados a {name}","{success} contatos adicionados a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adicionando {success} contato a {name}","Adicionando {success} contatos a {name}","Adicionando {success} contatos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} erro","{count} erros","{count} erros"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contato para {addressbook}","Importando %n contatos para {addressbook}","Importando %n contatos para {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importação concluída de %n contato para {addressbook}","Importação concluída de %n contatos para {addressbook}","Importação concluída de %n contatos para {addressbook}"],
    "No data for this contact" : "Sem dados para este contato",
    "No data for this contact on their profile" : "Sem dados para este contato em seu perfil",
    "Import" : "Importar",
    "Are you sure you want to import this contact file?" : "Tem certeza de que deseja importar este arquivo de contato?",
    "Could not copy" : "Não foi possível copiar",
    "Join team" : "Entrar na equipe",
    "You are about to leave {circle}.\nAre you sure?" : "Você está prestes a sair do {circle}.\nTem certeza?",
    "Please confirm team leave" : "Confirme a saída da equipe",
    "Could not leave the team {displayName}" : "Não foi possível sair da equipe {displayName}",
    "Unable to join the team" : "Não é possível entrar na equipe",
    "You are about to delete {circle}.\nAre you sure?" : "Você está prestes a excluir {circle}.\nTem certeza?",
    "Please confirm team deletion" : "Confirme a exclusão da equipe",
    "Unable to delete the team" : "Não foi possível excluir a equipe",
    "Confirm enabling federation" : "Confirmar a ativação da federação",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Ativar essa opção impedirá que {circle} seja membro de outras equipes.\nTem certeza?",
    "Enable federation" : "Ativar federação",
    "Link copied to the clipboard" : "Link copiado para a área de transferência",
    "Could not copy link to the clipboard." : "Não foi possível copiar o link para a área de transferência.",
    "Not grouped" : "Não agrupado",
    "Organization chart" : "Organograma",
    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Equipes são grupos de pessoas que você mesmo pode criar e com quem pode compartilhar dados. Eles podem ser formados por outras contas ou grupos de contas da instância Nextcloud, mas também por contatos do seu catálogo de endereços ou mesmo por pessoas externas, bastando inserir seus endereços de e-mail.",
    "Team" : "Equipe",
    "User" : "Usuário",
    "Group" : "Grupo",
    "Email" : "E-mail",
    "Contact" : "Contactar",
    "Moderator" : "Moderador",
    "Admin" : "Admin",
    "Owner" : "Proprietário",
    "Invites" : "Convites",
    "Anyone can request membership" : "Qualquer pessoa pode solicitar adesão",
    "Members need to accept invitation" : "Os membros precisam aceitar o convite",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "As adesões devem ser confirmadas/aceitas por um moderador (requer \"Qualquer pessoa pode solicitar adesão\")",
    "Members can also invite" : "Os membros também podem convidar",
    "Membership" : "Afiliação",
    "Prevent teams from being a member of another team" : "Impedir que equipes sejam membros de outra equipe",
    "Federation" : "Federação",
    "Allow federated members" : "Permitir membros federados",
    "Privacy" : "Privacidade",
    "Visible to everyone" : "Visível para todos",
    "users" : "usuários",
    "Users" : "Usuários",
    "groups" : "grupos",
    "federated users" : "usuários federados",
    "Federated users" : "Usuários federados",
    "teams" : "equipes",
    "email addresses" : "endereços de e-mail",
    "Email addresses" : "Endereço de e-mail",
    "contacts" : "contatos",
    "Detailed name" : "Nome detalhado",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "Nickname" : "Apelido",
    "Notes" : "Anotações",
    "Website" : "Website",
    "Location" : "Localização",
    "Federated Cloud ID" : "ID de Nuvem Federada",
    "Home" : "Casa",
    "Work" : "Trabalho",
    "Other" : "Outro",
    "Address" : "Endereço",
    "Post office box" : "Caixa de correio",
    "Extended address" : "Endereço estendido",
    "City" : "Cidade",
    "State or province" : "Estado ou província",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Aniversário",
    "Place of birth" : "Local de nascimento",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data do óbito",
    "Place of death" : "Local do óbito",
    "Instant messaging" : "Mensagem instantânea",
    "Phone" : "Telefone",
    "Mobile" : "Celular",
    "Work mobile" : "Celular do trabalho",
    "Home mobile" : "Celular pessoal",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do trabalho",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Car" : "Carro",
    "Work pager" : "Pager do trabalho",
    "Line manager" : "Superior hierárquico",
    "Social network" : "Rede social",
    "Relationship to you" : "Relacionado com você",
    "Spouse" : "Esposo(a)",
    "Child" : "Filho(a)",
    "Mother" : "Mãe",
    "Father" : "Pai",
    "Parent" : "Pais",
    "Brother" : "Irmão",
    "Sister" : "Irmã",
    "Relative" : "Parente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Assistente",
    "Related contacts" : "Contatos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergência",
    "Co-worker" : "Colega de trabalho",
    "Gender" : "Gênero",
    "Female" : "Mulher",
    "Male" : "Homem",
    "Unknown" : "Desconhecido",
    "Time zone" : "Fuso horário ",
    "Spoken languages" : "Idiomas falados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contato falhou ao ler","{failed} contatos falharam ao ler","{failed} contatos falharam ao ler"],
    "An error has occurred in team(s). Check the console for more details." : "Ocorreu um erro na(s) equipe(s). Verifique o console para mais detalhes.",
    "Unable to create team {circleName}" : "Não foi possível criar a equipe {circleName}",
    "Unable to delete team {circleId}" : "Não foi possível excluir a equipe {circleId}",
    "Unable to delete contact" : "Não foi possível excluir o contato",
    "Value copied to the clipboard" : "Valor copiado para a área de transferência",
    "Could not copy value to the clipboard." : "Não foi possível copiar o valor para a área de transferência."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
