OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importa contatti",
    "Details" : "Dettagli",
    "All contacts" : "Tutti i contatti",
    "Contacts" : "Contatti",
    "A contacts app for Nextcloud" : "Un'applicazione di contatti per Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "L'applicazione Contatti di Nextcloud è un'interfaccia utente per il server CardDAV di Nextcloud. Sincronizza i contatti in modo semplice da diversi dispositivi con il tuo Nextcloud e li modifica in linea.\n\n* 🚀 **Integrazione con altre applicazioni di Nextcloud!** Attualmente Posta e Calendario – altre arriveranno.\n* 🎉 **Non dimenticare mai un compleanno!** Puoi sincronizzare i compleanni e gli altri eventi ricorrenti con il tuo calendario di Nextcloud.\n* 👥 **Condivisione di rubriche!** Desideri condividere i tuoi contatti con i tuoi amici o colleghi? Nessun problema!\n* 🙈 **Non stiamo reinventando la ruota!** Basata sull'ottima libreria open source SabreDAV.",
    "Copy to full name" : "Copia nel nome completo",
    "Omit year" : "Ometti l'anno",
    "Allow updating avatars from social media" : "Consenti l'aggiornamento degli avatar dalle reti sociali",
    "There was an error fetching the member list" : "Si è verificato un errore durante il recupero della lista dei membri",
    "Please select a team" : "Seleziona un team",
    "Loading team…" : "Caricamento del team…",
    "Loading contacts …" : "Caricamento dei contatti …",
    "There are no contacts yet" : "Non ci sono ancora contatti",
    "Create contact" : "Crea contatto",
    "There are no contacts in this group" : "Non ci sono contatti in questo gruppo",
    "Create contacts" : "Crea contatti",
    "Add contacts" : "Aggiungi contatti",
    "Loading …" : "Caricamento …",
    "Manage team" : "Gestisci il team",
    "Leave team" : "Abbandona il team",
    "Delete team" : "Elimina il team",
    "Setting saved" : "Impostazioni salvate",
    "Contacts settings" : "Impostazioni Contatti",
    "General" : "Generale",
    "Update avatars from social media" : "Aggiorna gli avatar dalle reti sociali",
    "Address books" : "Rubriche",
    "Rename" : "Rinomina",
    "Export" : "Esporta",
    "Send email" : "Invia email",
    "Send email as BCC" : "Invia email come CCN",
    "Delete" : "Elimina",
    "Show all groups" : "Mostra tutti i gruppi",
    "Collapse groups" : "Contrai i gruppi",
    "Show all teams" : "Mostra tutti i team",
    "Collapse teams" : "Appiattisci team",
    "Group name cannot be empty" : "Il nome del gruppo non può essere vuoto",
    "This group already exists" : "Questo gruppo esiste già",
    "An error occurred while creating the group" : "Si è verificato un errore durante la creazione del gruppo",
    "This team already exists" : "Questo team esiste già",
    "An error happened during the creation of the team" : "Si è verificato un errore durante la creazione del team",
    "Recently contacted" : "Contattati di recente",
    "Contact groups" : "Gruppo di contatti",
    "Create a new contact group" : "Crea un nuovo gruppo di contatti",
    "Contact group name" : "Nome gruppo contatti",
    "Teams" : "Team",
    "Create a new team" : "Crea un nuovo team",
    "Open the contacts app settings" : "Apri le impostazioni dell'applicazione Contatti",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Condiviso con {num} entità","Condiviso con {num} entità","Condiviso con {num} entità"],
    "Copied" : "Copiato",
    "Cannot copy" : "Impossibile copiare",
    "Copy link" : "Copia collegamento",
    "Toggling of address book was not successful" : "L'abilitazione della rubrica non è riuscita",
    "This will delete the address book and every contacts within it" : "Questo eliminerà la rubrica e ogni contatto in essa contenuto",
    "Delete {addressbook}?" : "Eliminare {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Ciò annullerà la condivisione della rubrica e di tutti i contatti in essa contenuti",
    "Unshare {addressbook}?" : "Annullare condivisione di{addressbook}?",
    "Deletion of address book was not successful." : "L'eliminazione della rubrica non è riuscita.",
    "Renaming of address book was not successful." : "La rinomina della rubrica non è riuscita.",
    "Download" : "Scarica",
    "Show" : "Mostra",
    "Unshare from me" : "Annulla condivisione da me",
    "_%n contact_::_%n contacts_" : ["%n contatto","%n contatti","%n contatti"],
    "_%n group_::_%n groups_" : ["%n gruppo","%n gruppi","%n gruppi"],
    "Share with users or groups" : "Condividi con utenti o gruppi",
    "Share with users" : "Condividi con utenti",
    "No users or groups" : "Nessun utente o gruppo",
    "Unable to delete the share" : "Impossibile eliminare la condivisione",
    "Unable to change permissions" : "Impossibile cambiare i permessi",
    "Choose a vCard file to import" : "Scegli un file vCard da importare",
    "Import into the {addressbookName} address book" : "Importa nella rubrica {addressbookName}",
    "Select local file" : "Seleziona file locale",
    "Import from files" : "Importa da file",
    "Importing is disabled because there are no address books available" : "L'importazione è  disabilitata poiché non ci sono rubriche disponibili",
    "An error occurred, unable to create the address book" : "Si è  verificato un errore, impossibile creare la rubrica",
    "New address book" : "Nuova rubrica",
    "Add new address book" : "Aggiungi nuova rubrica",
    "Cancel" : "Annulla",
    "Add" : "Aggiungi",
    "First name" : "Nome",
    "Last name" : "Cognome",
    "Phonetic first name" : "Nome fonetico",
    "Phonetic last name" : "Cognome fonetico",
    "Display name" : "Nome visualizzato",
    "Last modified" : "Ultima modifica",
    "Sort contacts by" : "Ordina i contatti per",
    "Manages" : "Gestisci",
    "Oversees" : "Supervisiona",
    "An error happened during the config change" : "Si è verificato un errore durante il cambio di configurazione",
    "Enforce password protection on files shared to this team" : "Applica la protezione tramite password ai file condivisi con questo team",
    "Use a unique password for all shares to this team" : "Utilizza una password univoca per tutte le condivisioni di questo team",
    "Unique password …" : "Password univoca …",
    "Save" : "Salva",
    "Change unique password" : "Cambia password unica",
    "Failed to save password. Please try again later." : "Impossibile salvare la password. Riprova più tardi.",
    "Close" : "Chiudi",
    "There is no description for this team" : "Non esiste una descrizione per questo team",
    "Enter a description for the team" : "Inserisci una descrizione per il team",
    "Folder" : "Cartella",
    "New folder" : "Nuova cartella",
    "Folder name" : "Nome della cartella",
    "Conversation name" : "Nome della conversazione",
    "Calendar" : "Calendario",
    "New calendar" : "Nuovo calendario",
    "Calendar name" : "Nome del calendario",
    "An error happened while saving {fields}" : "Si è verificato un errore durante il salvataggio {fields}",
    "Team name" : "Nome del team",
    "Team owner" : "Proprietario del team",
    "Edit" : "Modifica",
    "Request to join" : "Richiedi di entrare",
    "Create" : "Crea",
    "Show in Calendar" : "Mostra nel calendario",
    "Your request to join this team is pending approval" : "La tua richiesta di adesione a questo team è in attesa di approvazione",
    "You are not a member of {circle}" : "Non sei un membro di {circle}",
    "Members" : "Membri",
    "Confirm" : "Confermi",
    "Add more info" : "Aggiungi più informazioni",
    "More fields" : "Altri campi",
    "Please select a valid format" : "Seleziona un formato valido",
    "Invalid image" : "Immagine non valida",
    "Error cropping picture" : "Errore durante il ritaglio dell'immagine",
    "Pick an avatar" : "Scegli un avatar",
    "Pick" : "Scelta",
    "Error while processing the picture." : "Errore durante l'elaborazione dell'immagine.",
    "Avatar downloaded from social network" : "Avatar scaricato dalla rete sociale",
    "Avatar already up to date" : "Avatar già aggiornato",
    "Avatar download failed" : "Scaricamento dell'avatar non riuscito",
    "Crop contact photo" : "Ritaglia foto contatto",
    "Upload a new picture" : "Carica una nuova immagine",
    "Choose from Files" : "Scegli da File",
    "Download picture" : "Scarica immagine",
    "Delete picture" : "Elimina immagine",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Questo contatto è in modalità di sola lettura. Non hai i permessi per modificare questo contatto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Il contatto che stavi tentando di modificare è cambiato. Aggiorna manualmente il contatto. Qualsiasi modifica ulteriore sarà scartata.",
    "Address book" : "Rubrica",
    "Add contact to Birthday Calendar" : "Aggiungi un contatto al calendario dei compleanni",
    "Exclude contact from Birthday Calendar" : "Escludere il contatto dal calendario dei compleanni",
    "{title} at {organization}" : "{title} in {organization}",
    "Name" : "Nome",
    "Syntax error. Cannot open the contact." : "Errore di sintassi. Impossibile aprire il contatto.",
    "The contact does not exist on the server anymore." : "Il contatto non esiste più nel server.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Impossibile recuperare il contatto dal server, controlla la connessione di rete.",
    "An error occurred while trying to move the contact" : "Si è verificato un errore durante il tentativo di spostare il contatto",
    "An error occurred while trying to copy the contact" : "Si è verificato un errore durante il tentativo di copiare il contatto",
    "Unable to update contact" : "Impossibile aggiornare il contatto",
    "No contact selected" : "Nessun contatto selezionato",
    "Select a contact on the list to begin" : "Seleziona un contatto dall'elenco per iniziare",
    "Title" : "Titolo",
    "Company" : "Azienda",
    "Go to talk conversation" : "Vai alla conversazione",
    "View profile" : "Vedi profilo",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Questo contatto era danneggiato e ha ricevuto una correzione. Rivedi il contenuto e fai clic qui per salvarlo.",
    "Edit profile" : "Modifica il profilo",
    "Clone contact" : "Clona contatto",
    "Generate QR Code" : "Genera codice QR",
    "Contact vCard as QR code" : "vCard del contatto come codice QR",
    "Pick an address book" : "Scegli una rubrica",
    "Select address book" : "Seleziona rubrica",
    "Media shares with you" : "Condivisioni multimediali con te",
    "Talk conversations with you" : "Conversazioni di Talk con te",
    "Calendar events with you" : "Calendario eventi con te",
    "Deck cards with you" : "Deck di cards con te",
    "No shared items with this contact" : "Nessun elemento condiviso con questo contatto",
    "Select groups" : "Seleziona gruppi",
    "Select addressbook" : "Seleziona rubrica",
    "Selected contacts" : "Contatti selezionati",
    "Move" : "Sposta",
    "Confirm merging contacts" : "Conferma l'unione dei contatti",
    "The selected contacts have conflicting information. Choose which information to keep" : "I contatti selezionati contengono informazioni contrastanti. Scegli quali informazioni conservare",
    "Contacts can be merged" : "I contatti possono essere uniti",
    "Groups" : "Gruppi",
    "Select groups to add the merged contact to" : "Seleziona i gruppi a cui aggiungere il contatto unito",
    "Merge contacts" : "Unisci i contatti",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Elimina {number} contatto","Elimina {number} contatti","Elimina {number} contatti"],
    "Please select at least one editable contact to delete" : "Seleziona almeno un contatto modificabile da eliminare",
    "Please select two editable contacts to merge" : "Seleziona due contatti modificabili da unire",
    "Are you sure you want to proceed?" : "Sei sicuro di voler procedere?",
    "Add contacts to group" : "Aggiungi contatti a gruppo",
    "Search contacts …" : "Cerca contatti …",
    "Unselect {number}" : "Deseleziona {number}",
    "Add to {group}" : "Aggiungi a {group}",
    "Add members to {group}" : "Aggiungi membri a {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Si prega di notare che è possibile aggiungere contatti ai gruppi di contatti solo da rubriche con accesso in scrittura. Non è possibile aggiungere contatti da rubriche di sola lettura, come la rubrica di sistema.",
    "Remove {type}" : "Rimuovi {type}",
    "Add to group" : "Aggiungi a gruppo",
    "Add members to group" : "Aggiungi membri al gruppo",
    "Search {types}" : "Cerca {types}",
    "Add guest" : "Aggiungi ospite",
    "Search for people to add" : "Cerca persone da aggiungere",
    "No results" : "Nessun risultato",
    "Add {type}" : "Aggiungi {type}",
    "New team name" : "Nuovo nome del team",
    "Personal team" : "Team personale",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Questo team sarà visibile solo a te. Gli altri membri non potranno vederlo o utilizzarlo.",
    "Local team" : "Team locale",
    "This team will not be shared with the other instances of the global scale" : "Questo team non verrà condiviso con le altre istanze su scala globale",
    "Create team" : "Crea team",
    "Promote as sole owner" : "Promuovi come unico proprietario",
    "Promote to {level}" : "Promuovi a {level}",
    "Demote to {level}" : "Declassa a {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Vuoi davvero abbandonare questo team? Questa azione non può essere annullata.",
    "Leave team failed." : "L'abbandono del team è fallito.",
    "Could not delete the member {displayName}" : "Impossibile eliminare il membro {displayName}",
    "Could not change the member level to {level}" : "Impossibile cambiare il livello del membro a {level}",
    "Could not accept membership request" : "Impossibile accettare la richiesta di adesione",
    "Accept membership request" : "Accetta la richiesta di adesione",
    "Reject membership request" : "Rifiuta la richiesta di adesione",
    "Manage level" : "Gestisci livello",
    "Remove member" : "Rimuovi membro",
    "Unable to get the results" : "Impossibile recuperare i risultati",
    "Some members could not be added" : "Alcuni membri non sono stati aggiunti",
    "There was an issue adding members to the team" : "Si è verificato un problema durante l'aggiunta di membri al team",
    "Loading members list …" : "Caricamento elenco membri …",
    "The list of members is only visible to members of this team" : "L'elenco dei membri è visibile solo ai membri di questo team",
    "You currently have no access to the member list" : "Al momento non hai accesso all'elenco dei membri",
    "Add to {team}" : "Aggiungi a {team}",
    "Invite members to {team}" : "Invita i membri a {team}",
    "Pending" : "In attesa",
    "Select chart …" : "Seleziona grafico …",
    "Chart" : "Grafico",
    "Select Date" : "Seleziona data",
    "Select type" : "Seleziona tipo",
    "Add contact in group" : "Aggiungi contatto a gruppo",
    "None" : "Nessuno",
    "Select option" : "Seleziona opzione",
    "note" : "nota",
    "email" : "email",
    "send an email" : "invia un'email",
    "Personal dates" : "Date personali",
    "Add property of this type" : "Aggiungi proprietà di questo tipo",
    "Member" : "Membro",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Questo è un gruppo di sola lettura gestito dagli amministratori. I membri del gruppo possono solo visualizzarlo.",
    "Unable to create the contact." : "Impossibile creare il contatto.",
    "Contact not found" : "Contatto non trovato",
    "Group {group} not found" : "Gruppo {group} non trovato",
    "Add member" : "Aggiungi membro",
    "New contact" : "Nuovo contatto",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contatto aggiunto a {name}","{success} contatti aggiunti a {name}","{success} contatti aggiunti a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Aggiunta di {success} contatto a {name}","Aggiunta di {success} contatti a {name}","Aggiunta di {success} contatti a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} errore","{count} errori","{count} errori"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importazione di %n contatto in {addressbook}","Importazione di %n contatti in {addressbook}","Importazione di %n contatti in {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importazione completata di %n contatto in {addressbook}","Importazione completata di %n contatti in {addressbook}","Importazione completata di %n contatti in {addressbook}"],
    "No data for this contact" : "Nessun dato per questo contatto",
    "No data for this contact on their profile" : "Nessun dato per questo contatto sul suo profilo",
    "Import" : "Importa",
    "Are you sure you want to import this contact file?" : "Sei sicuro di voler importare questo file di contatti?",
    "Could not copy" : "Impossibile copiare",
    "Join team" : "Unisciti al team",
    "You are about to leave {circle}.\nAre you sure?" : "Stai per abbandonare {circle}.\nSei sicuro?",
    "Please confirm team leave" : "Si prega di confermare l'uscita dal team",
    "Could not leave the team {displayName}" : "Non può lasciare il team {displayName}",
    "Unable to join the team" : "Impossibile unirsi al team",
    "You are about to delete {circle}.\nAre you sure?" : "Stai per eliminare {circle}.\nSei sicuro?",
    "Please confirm team deletion" : "Si prega di confermare l'eliminazione del team",
    "Unable to delete the team" : "Impossibile eliminare il team",
    "Link copied to the clipboard" : "Collegamento copiato negli appunti",
    "Could not copy link to the clipboard." : "Impossibile copiare negli appunti il collegamento.",
    "Not grouped" : "Non raggruppati",
    "Organization chart" : "Grafico organizzativo",
    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "I team sono gruppi di persone che puoi creare tu stesso e con cui puoi condividere dati. Possono essere composti da altri account o gruppi di account dell'istanza Nextcloud, ma anche da contatti della tua rubrica o anche da persone esterne inserendo semplicemente i loro indirizzi e-mail.",
    "Team" : "Team",
    "User" : "Utente",
    "Group" : "Gruppo",
    "Email" : "Posta elettronica",
    "Contact" : "Contatto",
    "Moderator" : "Moderatore",
    "Admin" : "Amministratore",
    "Owner" : "Proprietario",
    "Invites" : "Inviti",
    "Anyone can request membership" : "Chiunque può chiedere di entrare",
    "Members need to accept invitation" : "I membri devono accettare un invito",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Le iscrizioni devono essere confermate/accettate da un moderatore (richiede \"Chiunque può richiedere l'iscrizione\")",
    "Members can also invite" : "I membri possono anche invitare",
    "Membership" : "Membro del team",
    "Prevent teams from being a member of another team" : "Impedire ai team di essere membri di un altro team",
    "Privacy" : "Privacy",
    "Visible to everyone" : "Visibile a tutti",
    "users" : "utenti",
    "Users" : "Utenti",
    "groups" : "gruppi",
    "teams" : "team",
    "email addresses" : "indirizzi email",
    "Email addresses" : "Indirizzi email",
    "contacts" : "contatti",
    "Detailed name" : "Nome dettagliato",
    "Additional names" : "Nomi aggiuntivi",
    "Prefix" : "Prefisso",
    "Suffix" : "Suffisso",
    "Nickname" : "Pseudonimo",
    "Notes" : "Note",
    "Website" : "Sito web",
    "Location" : "Posizione",
    "Federated Cloud ID" : "ID di cloud federata",
    "Home" : "Home",
    "Work" : "Lavoro",
    "Other" : "Altro",
    "Address" : "Indirizzo",
    "Post office box" : "Casella postale",
    "Extended address" : "Indirizzo esteso",
    "City" : "Città",
    "State or province" : "Stato o regione",
    "Postal code" : "CAP",
    "Country" : "Nazione",
    "Birthday" : "Compleanno",
    "Place of birth" : "Luogo di nascita",
    "Anniversary" : "Anniversario",
    "Date of death" : "Data di morte",
    "Place of death" : "Luogo di morte",
    "Instant messaging" : "Messaggistica istantanea",
    "Phone" : "Telefono",
    "Mobile" : "Cellulare",
    "Work mobile" : "Cellulare lavoro",
    "Home mobile" : "Cellulare personale",
    "Fax" : "Fax",
    "Fax home" : "Fax casa",
    "Fax work" : "Fax lavoro",
    "Pager" : "Cercapersone",
    "Voice" : "Voce",
    "Car" : "Automobile",
    "Work pager" : "Cercapersone lavoro",
    "Line manager" : "Responsabile di linea",
    "Social network" : "Rete sociale",
    "Relationship to you" : "Rapporto con te",
    "Spouse" : "Coniuge",
    "Child" : "Figlio",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Genitore",
    "Brother" : "Fratello",
    "Sister" : "Sorella",
    "Relative" : "Parente",
    "Friend" : "Amico",
    "Colleague" : "Collega",
    "Assistant" : "Assistente",
    "Related contacts" : "Contatti correlati",
    "Agent" : "Agente",
    "Emergency" : "Emergenza",
    "Co-worker" : "Collega",
    "Gender" : "Sesso",
    "Female" : "Femmina",
    "Male" : "Maschio",
    "Unknown" : "Sconosciuto",
    "Time zone" : "Fuso orario",
    "Spoken languages" : "Lingue parlate",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["lettura di {failed} contatto non riuscita","lettura di {failed} contatti non riuscita","lettura di {failed} contatti non riuscita"],
    "An error has occurred in team(s). Check the console for more details." : "Si è verificato un errore nel team(s). Controlla la console per maggiori dettagli.",
    "Unable to create team {circleName}" : "Impossibile creare il team {circleName}",
    "Unable to delete team {circleId}" : "Impossibile eliminare il team\n{circleId}",
    "Unable to delete contact" : "Impossibile eliminare il contatto"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
