OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "导入联系人",
    "Details" : "详情",
    "All contacts" : "全部联系人",
    "_Imported %n contact_::_Imported %n contacts_" : ["已导入 %n 位联系人"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["（已跳过 %n 个联系人）"],
    "Contacts" : "联系人",
    "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud通讯录应用程序是Nextcloud的CardDAV服务器用户界面。您可以轻松使用您的Nextcloud同步各设备上的联系人，并在线上编辑。\n\n* 🚀 **与其他Nextcloud应用程序整合！** 目前有邮件和日历，还会有更多。\n* 🎉 **不会忘记生日！** 您可以将生日与其他重复的活动与您的Nextcloud日历同步。\n* 👥 **分享通讯录！** 您想与您的朋友或同事分享您的联系人吗？没问题！\n* 🙈 **我们不是在重复造轮子！** 基于出色且开源的SabreDAV库。",
    "Copy to full name" : "复制到全名",
    "Omit year" : "忽略年份",
    "Allow updating avatars from social media" : "允许从社交媒体资料更新头像",
    "There was an error fetching the member list" : "获取成员列表时发生一个错误",
    "Please select a team" : "请选择团队",
    "Loading team…" : "正在加载团队…",
    "Loading contacts …" : "正在加载联系人 …",
    "There are no contacts yet" : "尚无联系人",
    "Create contact" : "创建联系人",
    "There are no contacts in this group" : "此群组中没有联系人",
    "Create contacts" : "新建联系人",
    "Add contacts" : "添加联系人",
    "Loading …" : "正在加载 …",
    "Manage team" : "管理团队",
    "Leave team" : "离开团队",
    "Delete team" : "删除团队",
    "Setting saved" : "设置已保存",
    "Failed to save setting" : "无法保存设置",
    "Contacts settings" : "联系人设置",
    "General" : "常规",
    "Update avatars from social media" : "从社交媒体更新头像",
    "Refreshed once per week" : "每周刷新一次",
    "Address books" : "通讯录",
    "Tried to drop an invalid contact!" : "尝试删除无效联系人！",
    "Rename" : "重命名",
    "Export" : "导出",
    "Send email" : "发送邮件",
    "Send email as BCC" : "以抄送模式发送邮件",
    "Delete" : "删除",
    "Show all groups" : "显示全部群组",
    "Collapse groups" : "收起群组",
    "Show all teams" : "显示全部团队",
    "Collapse teams" : "收起团队",
    "Group name cannot be empty" : "群组名称不能为空",
    "This group already exists" : "此群组已存在",
    "An error occurred while creating the group" : "创建群组时出错",
    "This team already exists" : "此团队已存在",
    "An error happened during the creation of the team" : "创建团队时出错",
    "Recently contacted" : "最近联系",
    "Contact groups" : "联系人群组",
    "Create a new contact group" : "创建联系人群组",
    "Contact group name" : "联系人群组名称",
    "Teams" : "团队",
    "Create a new team" : "创建新团队",
    "Open the contacts app settings" : "打开联系人应用设置",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
    "Copied" : "已复制",
    "Cannot copy" : "无法复制",
    "Copy link" : "复制链接",
    "Toggling of address book was not successful" : "通讯录切换不成功",
    "This will delete the address book and every contacts within it" : "这将删除通讯录及其中的所有联系人",
    "Delete {addressbook}?" : "删除 {addressbook}？",
    "This will unshare the address book and every contacts within it" : "这将取消共享通讯录及其中的每位联系人",
    "Unshare {addressbook}?" : "取消共享 {addressbook}？ ",
    "Deletion of address book was not successful." : "通讯录删除不成功",
    "Renaming of address book was not successful." : "通讯录重命名不成功",
    "{addressbookname} (Hidden)" : "{addressbookname}（隐藏）",
    "Download" : "下载",
    "Show" : "显示",
    "Unshare from me" : "我取消的共享",
    "_%n contact_::_%n contacts_" : ["%n 位联系人"],
    "_%n group_::_%n groups_" : ["%n 个群组"],
    "Share with users or groups" : "与用户或者群组共享",
    "Share with users" : "共享给其他用户",
    "No users or groups" : "无用户或群组",
    "Unable to delete the share" : "无法删除共享",
    "Unable to change permissions" : "无法更改权限",
    "can create and edit" : "可以创建和编辑",
    "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
    "Import into the {addressbookName} address book" : "导入 {addressbookName} 通讯录",
    "Select local file" : "选择本地文件",
    "Import from files" : "从文件导入",
    "Importing is disabled because there are no address books available" : "导入已禁用，因为没有可用的通讯录",
    "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
    "New address book" : "新通讯录",
    "Add new address book" : "添加新通讯录",
    "Cancel" : "取消",
    "Add" : "添加",
    "First name" : "名",
    "Last name" : "姓",
    "Phonetic first name" : "语音名字",
    "Phonetic last name" : "语音姓氏",
    "Display name" : "显示名称",
    "Last modified" : "上一次更改",
    "Sort contacts by" : "排序联系人方式",
    "Manages" : "管理",
    "Oversees" : "监督",
    "An error happened during the config change" : "更改配置时发生一个错误",
    "Enforce password protection on files shared to this team" : "对与此团队共享的文件强制实施密码保护",
    "Use a unique password for all shares to this team" : "为此团队的全部共享使用唯一密码",
    "Unique password …" : "唯一密码 …",
    "Save" : "保存",
    "Change unique password" : "修改独立密码",
    "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
    "Close" : "关闭",
    "There is no description for this team" : "此团队没有描述",
    "Enter a description for the team" : "输入团队的描述",
    "Folder" : "文件夹",
    "New folder" : "新文件夹",
    "Folder name" : "文件夹名称",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "这将创建一个与团队共享的常规文件夹。要创建团队文件夹，请联系您的 {productName} 管理员",
    "Talk conversation" : "Talk 对话",
    "New Talk conversation" : "新 Talk 对话",
    "Conversation name" : "对话名称",
    "Collective" : "集体",
    "Calendar" : "日历",
    "New calendar" : "新日历",
    "Calendar name" : "日历名称",
    "Deck board" : "Deck 面板",
    "New Deck board" : "新 Deck 面板",
    "Board name" : "面板名称",
    "Deck app is not installed. Please install it to create team boards." : "未安装 Deck 应用。请安装它以创建团队面板。",
    "Unknown resource type" : "未知资源类型",
    "Team calendar \"{resourceName}\" created and shared with team" : "团队日历“{resourceName}”已创建并与团队共享",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType}“{resourceName}”已创建并与团队共享",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "名为“{name}”的日历已存在。请选择其他名称。",
    "Failed to create {resourceType}: {error}" : "无法创建 {resourceType}：{error}",
    "An error happened while saving {fields}" : "保存 {fields} 时出错",
    "Team name" : "团队名称",
    "Team owner" : "团队所有者",
    "Edit" : "编辑",
    "Request to join" : "请求加入",
    "Create" : "创建",
    "Show in Calendar" : "在日历中显示",
    "Your request to join this team is pending approval" : "您加入此团队的请求正在等待批准",
    "You are not a member of {circle}" : "您并非 {circle} 的成员",
    "Members" : "成员",
    "Confirm" : "确认",
    "Add more info" : "添加更多信息",
    "More fields" : "更多领域",
    "Please select a valid format" : "请选择有效格式",
    "Invalid image" : "无效的图像",
    "Error cropping picture" : "裁剪照片时发生错误",
    "Pick an avatar" : "选择一个头像",
    "Pick" : "选择",
    "Error while processing the picture." : "处理图片时出错。",
    "Avatar downloaded from social network" : "已从社交媒体下载头像",
    "Avatar already up to date" : "头像已是最新",
    "Avatar download failed" : "头像下载失败",
    "Crop contact photo" : "裁剪联系人照片",
    "Upload a new picture" : "上传一张新的图片",
    "Choose from Files" : "从文件中选择",
    "Download picture" : "下载图片",
    "Delete picture" : "删除图片",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
    "Address book" : "通讯录",
    "Add contact to Birthday Calendar" : "添加联系人到生日日历",
    "Exclude contact from Birthday Calendar" : "从生日日历中排除联系人",
    "{title} at {organization}" : "{organization} 的 {title}",
    "Name" : "名称",
    "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
    "The contact does not exist on the server anymore." : "服务器上不再存在此联系人。",
    "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器获取联系人，请检查您的网络连接。",
    "An error occurred while trying to move the contact" : "尝试移动联系人时出错",
    "An error occurred while trying to copy the contact" : "尝试复制联系人时出错",
    "Unable to update contact" : "无法更新联系人",
    "No contact selected" : "请选择联系人",
    "Select a contact on the list to begin" : "请先在列表里选择联系人",
    "Title" : "头衔",
    "Company" : "公司",
    "Go to talk conversation" : "前往对话",
    "View profile" : "查看个人资料",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人资料损坏但已被修复。请查看内容并点击这里以保存它。",
    "Edit profile" : "编辑个人资料",
    "Clone contact" : "克隆联系人",
    "Generate QR Code" : "生成二维码",
    "Contact vCard as QR code" : "联系人名片作为二维码",
    "Pick an address book" : "选择一个通讯录",
    "Select address book" : "选择通讯录",
    "Media shares with you" : "与您分享的媒体",
    "Talk conversations with you" : "与您展开的对话",
    "Calendar events with you" : "与您分享的日历事件",
    "Deck cards with you" : "与您分享的卡片",
    "No shared items with this contact" : "与该联系人无共享项目",
    "This contact cannot be moved" : "此联系人无法移动",
    "This contact cannot be grouped" : "此联系人无法分组",
    "Add contacts to groups" : "添加联系人到群组",
    "Move contacts to addressbook" : "移动联系人到通讯录",
    "Select groups" : "选择群组",
    "Select addressbook" : "选择通讯录",
    "Selected contacts" : "已选择联系人",
    "Please note that only {count} of the {total} contacts can be added to a group" : "请注意，{total} 位联系人中只有 {count} 位可以添加到群组中",
    "Please note that only {count} of the {total} contacts can be moved" : "请注意，{total} 位联系人中只有 {count} 位可以移动。",
    "Move" : "移动",
    "from {addressbook}" : "从 {addressbook}",
    "Confirm merging contacts" : "确认合并联系人",
    "The selected contacts have conflicting information. Choose which information to keep" : "所选联系人的信息存在冲突。请选择要保留的信息",
    "Contacts can be merged" : "联系人可以合并",
    "Groups" : "群组",
    "Select groups to add the merged contact to" : "选择要添加合并联系人的群组",
    "Merge contacts" : "合并联系人",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["删除 {number} 位联系人"],
    "Please select at least one editable contact to delete" : "请至少选择一个可编辑的联系人进行删除",
    "Please select two editable contacts to merge" : "请选择两个可编辑的联系人进行合并",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["添加 {number} 位联系人到群组"],
    "Please select at least one editable contact to add to a group" : "请至少选择一位可编辑的联系人以添加到群组中",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["移动 {number} 位联系人到通讯录"],
    "Please select at least one editable contact to move to an addressbook" : "请至少选择一位可编辑的联系人以移动到通讯录中",
    "Are you sure you want to proceed?" : "是否确定要继续？",
    "Add contacts to group" : "添加联系人到群组",
    "Search contacts …" : "搜索联系人 …",
    "Unselect {number}" : "取消选择 {number}",
    "Add to {group}" : "添加到 {group}",
    "Add members to {group}" : "添加成员到 {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "请注意，您只能将可写通讯录中的联系人添加到联系人组。无法添加只读通讯录（如系统通讯录）中的联系人。",
    "Remove {type}" : "移除 {type}",
    "Add to group" : "添加到群组",
    "Add members to group" : "添加成员到群组",
    "Search {types}" : "搜索 {types}",
    "Add guest" : "添加访客",
    "Search for people to add" : "搜索要添加的联系人",
    "No results" : "无结果",
    "Add {type}" : "添加  {type}",
    "New team name" : "新团队名称",
    "Personal team" : "个人团队",
    "This team will only be visible to you. Other members will not be able to see or use it." : "此团队仅对您可见，其他成员将无法看到或使用它。",
    "Local team" : "本地团队",
    "This team will not be shared with the other instances of the global scale" : "此团队不会与全局范围内的其他实例共享",
    "Create team" : "创建团队",
    "Promote as sole owner" : "提升为唯一所有人",
    "Promote to {level}" : "提升为 {level}",
    "Demote to {level}" : "降级为 {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "是否确定要离开此团队？此操作无法撤销。",
    "Leave team failed." : "离开团队失败。",
    "Could not delete the member {displayName}" : "无法删除成员 {displayName}",
    "Could not change the member level to {level}" : "无法更改成员级别到 {level}",
    "Could not accept membership request" : "无法接受成员身份请求",
    "Accept membership request" : "接受成员身份请求",
    "Reject membership request" : "拒绝成员身份请求",
    "Manage level" : "管理级别",
    "Remove member" : "移除成员",
    "Unable to get the results" : "无法获得结果",
    "Some members could not be added" : "无法添加一些成员",
    "There was an issue adding members to the team" : "向团队添加成员时出现问题",
    "Loading members list …" : "正在加载成员列表 …",
    "The list of members is only visible to members of this team" : "成员列表仅对此团队的成员可见",
    "You currently have no access to the member list" : "您目前无法访问成员列表",
    "Add to {team}" : "添加到 {team}",
    "Invite members to {team}" : "邀请成员加入 {team}",
    "Pending" : "待定",
    "Select chart …" : "选择图表 …",
    "Chart" : "图表",
    "Select Date" : "选择日期",
    "Select type" : "选择类型",
    "Add contact in group" : "添加联系人到群组",
    "None" : "无",
    "copy" : "复制",
    "Select option" : "选择选项",
    "note" : "备注",
    "email" : "电子邮件",
    "send an email" : "发送邮件",
    "Personal dates" : "个人行程",
    "Add property of this type" : "为此类型添加属性",
    "Member" : "成员",
    "This is a read-only group managed by administrators. Group members can only view this group." : "这是由管理员管理的只读组。组成员只能查看此组。",
    "Unable to create the contact." : "未能成功创建联系人。",
    "Contact not found" : "未找到联系人",
    "Group {group} not found" : "未找到群组 {group} ",
    "Add member" : "添加成员",
    "New contact" : "新建联系人",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 位联系人已添加到 {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["正在将 {success} 位联系人添加到 {name}"],
    "_{count} error_::_{count} errors_" : ["{count} 个错误"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在将 %n 位联系人导入 {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 位联系人导入 {addressbook}"],
    "No data for this contact" : "此联系人无数据",
    "No data for this contact on their profile" : "此联系人的个人资料中没有相关数据",
    "Import" : "导入",
    "Are you sure you want to import this contact file?" : "您确定您想要导入此联系人文件吗？",
    "Could not copy" : "无法复制",
    "Join team" : "加入团队",
    "You are about to leave {circle}.\nAre you sure?" : "您即将离开 {circle}\n确定吗？",
    "Please confirm team leave" : "请确认离开团队 ",
    "Could not leave the team {displayName}" : "无法离开团队 {显示名称}",
    "Unable to join the team" : "无法加入团队",
    "You are about to delete {circle}.\nAre you sure?" : "您即将删除 {circle}\n确定吗？",
    "Please confirm team deletion" : "请确认删除团队",
    "Unable to delete the team" : "无法删除团队",
    "Confirm enabling federation" : "确认启用联合",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "启用后，{circle} 将无法加入其他团队。\n您确定吗？",
    "Enable federation" : "启用联合",
    "Link copied to the clipboard" : "链接已复制到剪贴板",
    "Could not copy link to the clipboard." : "无法复制链接到剪贴板",
    "Not grouped" : "未分组",
    "Organization chart" : "组织图",
    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "团队是一群人，您可以自己创建，也可以与他们共享数据。它们可以由 Nextcloud 实例的其它账号或账号组组成，也可以由通讯录中的联系人组成，甚至可以由外部人员组成，只需输入他们的电子邮件地址即可。",
    "Team" : "团队",
    "User" : "用户",
    "Group" : "群组",
    "Email" : "电子邮件",
    "Contact" : "联系人",
    "Moderator" : "主持人",
    "Admin" : "管理员",
    "Owner" : "所有者",
    "Invites" : "邀请",
    "Anyone can request membership" : "任何人均可请求成员资格",
    "Members need to accept invitation" : "成员需要接受邀请",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成员资格必须由主持人确认/接受（要求“任何人都可以申请成员资格”）",
    "Members can also invite" : "成员也可以邀请",
    "Membership" : "成员资格",
    "Prevent teams from being a member of another team" : "防止团队成为其他团队的成员",
    "Federation" : "联合",
    "Allow federated members" : "允许联合成员",
    "Privacy" : "隐私",
    "Visible to everyone" : "对所有人可见",
    "users" : "用户",
    "Users" : "用户",
    "groups" : "群组",
    "federated users" : "联合用户",
    "Federated users" : "联合用户",
    "teams" : "团队",
    "email addresses" : "电子邮件地址",
    "Email addresses" : "电子邮件地址",
    "contacts" : "联系人",
    "Detailed name" : "全名",
    "Additional names" : "其他名称",
    "Prefix" : "前缀",
    "Suffix" : "后缀",
    "Nickname" : "昵称",
    "Notes" : "备注",
    "Website" : "网站",
    "Location" : "地点",
    "Federated Cloud ID" : "联合云 ID",
    "Home" : "家庭",
    "Work" : "工作",
    "Other" : "其它",
    "Address" : "地址",
    "Post office box" : "邮政信箱",
    "Extended address" : "附加地址",
    "City" : "城市",
    "State or province" : "州/省",
    "Postal code" : "邮政编码",
    "Country" : "国家",
    "Birthday" : "生日",
    "Place of birth" : "出生地",
    "Anniversary" : "周年",
    "Date of death" : "去世日期",
    "Place of death" : "死亡地",
    "Instant messaging" : "即时通讯",
    "Phone" : "电话",
    "Mobile" : "手机",
    "Work mobile" : "工作电话",
    "Home mobile" : "家庭移动电话",
    "Fax" : "传真",
    "Fax home" : "家庭传真",
    "Fax work" : "工作传真",
    "Pager" : "传呼机",
    "Voice" : "语音",
    "Car" : "车",
    "Work pager" : "工作传呼机",
    "Line manager" : "部门经理",
    "Social network" : "社交网络",
    "Relationship to you" : "和您的关系",
    "Spouse" : "配偶",
    "Child" : "子女",
    "Mother" : "母亲",
    "Father" : "父亲",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姐妹",
    "Relative" : "关系",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Assistant" : "助理",
    "Related contacts" : "相关联系人",
    "Agent" : "代理",
    "Emergency" : "紧急",
    "Co-worker" : "同事",
    "Gender" : "性别",
    "Female" : "女性",
    "Male" : "男性",
    "Unknown" : "未知",
    "Time zone" : "时区",
    "Spoken languages" : "口语",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 位联系人无法读取"],
    "An error has occurred in team(s). Check the console for more details." : "团队中出现错误。有关更多详情，请查看控制台。",
    "Unable to create team {circleName}" : "无法创建团队 {circleName}",
    "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
    "Unable to delete contact" : "无法删除联系人",
    "Value copied to the clipboard" : "值已复制到剪贴板",
    "Could not copy value to the clipboard." : "无法将值复制到剪贴板。"
},
"nplurals=1; plural=0;");
