OC.L10N.register(
    "contacts",
    {
    "Details" : "Sīkāka informācija",
    "All contacts" : "Visas kontaktpersonas",
    "Contacts" : "Kontakti",
    "A contacts app for Nextcloud" : "Nextcloud kontaktpersonu lietotne",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Kontaktpersonu lietotne ir Nextcloud iebūvētā CardDAV servera grafiskā saskarne. Tas ļauj vienkārši sinhronizēt kontaktpersonu informāciju no vairākām ierīcēm ar Tavu Nextcloud serveri un labot tās tiešsaistē.\n\n* 🚀 **Savienojums ar citām Nextcloud lietotnēm.** Pašlaik ar pastu un kalendāru - drīzumā vēl.\n* 🎉  **Nekad neaizmirsti kāda dzimšanas dienu!** Tu vari sinhronizēt dzimšanas dienas un citas atkārtojošos notikumus ar savu Nextcloud kalendāru.\n* 👥 **Adrešu grāmatu kopīgošana.** Vēlies kopīgot savas kontaktpersonas ar saviem draugiem vai darbabiedriem? Kāda runa!\n* 🙈 **Mēs nemēģinām no jaunaizgudrot riteni.** Balstīta uz lieliskās atvērtā koda bibliotēkas SabreDAV.",
    "Copy to full name" : "Kopēt uz pilnu vārdu",
    "Omit year" : "Izlaiduma gads",
    "Contacts settings" : "Kontaktpersonu iestatījumi",
    "Address books" : "Adrešu grāmatas",
    "Rename" : "Pārdēvēt",
    "Send email" : "Sūtīt e-pasta ziņojumu",
    "Delete" : "Dzēst",
    "Contact groups" : "Kontaktpersonu kopas",
    "Create a new contact group" : "Izveidot jaunu kontaktpersonu kopu",
    "Contact group name" : "Kontaktpersonu kopas nosaukums",
    "Teams" : "Komandas",
    "Open the contacts app settings" : "Atvērt kontaktpersonu lietotnes iestatījumus",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Kopīgots ar {num} entītijām","Kopīgots ar {num} entītiju","Kopīgots ar {num} entītijām"],
    "Copied" : "Nokopēts",
    "Copy link" : "Ievietot saiti starpliktuvē",
    "Delete {addressbook}?" : "Izdzēst {addressbook}?",
    "Unshare {addressbook}?" : "Atcelt {addressbook} koplietošanu?",
    "Deletion of address book was not successful." : "Adrešu grāmatas izdzēšana nebija sekmīga.",
    "Renaming of address book was not successful." : "Adrešu grāmatas pārdēvēšana nebija sekmīga",
    "Download" : "Lejupielādēt",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "Import into the {addressbookName} address book" : "Ievietot adrešu grāmatā \"{addressbookName}\"",
    "Import from files" : "Ievietot no datnēm",
    "Importing is disabled because there are no address books available" : "Ievietošana ir atspējota, jo nav pieejama neviena adrešu grāmata",
    "Cancel" : "Atcelt",
    "Add" : "Pievienot",
    "First name" : "Vārds",
    "Last name" : "Uzvārds",
    "Display name" : "Ekrāna vārds",
    "Last modified" : "Pēdējoreiz izmainīts",
    "Save" : "Saglabāt",
    "Close" : "Aizvērt",
    "Edit" : "Labot",
    "Create" : "Izveidot",
    "More fields" : "Vairāk lauku",
    "Invalid image" : "Nederīgs attēls",
    "Pick an avatar" : "Izvēlēties avataru",
    "Error while processing the picture." : "Apstrādājot attēlu, radās kļūda.",
    "Upload a new picture" : "Augšupielādēt jaunu attēlu",
    "Download picture" : "Lejupielādēt attēlu",
    "Delete picture" : "Dzēst attēlu",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šī kontaktpersona ir tikai lasāma. Tev nav atļaujas labot šo kontaktpersonu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontaktpersona, kuras informāciju mēģināji labot, ir mainījusies. Lūgums pašrocīgi atsvaidzināt kontaktpersonas informāciju. Jebkuras turpmākās izmaiņas tiks atmestas.",
    "Name" : "Vārds",
    "Syntax error. Cannot open the contact." : "Sintakse kļūda. Nevar atvērt kontaktpersonu.",
    "No contact selected" : "Nav izvēlēta kontaktpersona",
    "Select a contact on the list to begin" : "Jāatlasa kontaktpersona no saraksta, lai sāktu",
    "Title" : "Amats",
    "Company" : "Uzņēmums",
    "Edit profile" : "Labot profilu",
    "Generate QR Code" : "Izveidot kvadrātkodu",
    "Move" : "Move",
    "No results" : "Nav iznākuma",
    "Pending" : "Gaida",
    "Select Date" : "Atlasīt datumu",
    "Select type" : "Atlasīt veidu",
    "Add contact in group" : "Pievienot kontaktpersonu grupai",
    "None" : "Nav",
    "Select option" : "Atlasīt iespēju",
    "Unable to create the contact." : "Nevar izveidot kontaktpersonu.",
    "Contact not found" : "Kontaktpersona nav atrasta!",
    "New contact" : "Jauna kontaktpersona",
    "Import" : "Ievieto",
    "Not grouped" : "Negrupēts",
    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Komandas ir cilvēku kopas, kuras vari izveidot un ar kurām vari kopīgot datus· Tās var būt veidotas no citiem Nextcloud servera kontiem vai kontu kopām, kā arī kontaktpersonām no Tavas adrešu grāmatas vai pat ārējiem cilvēkiem, vienkārši ievadot to e-pasta adresi.",
    "User" : "Lietotājs",
    "Group" : "Grupa",
    "Email" : "E-pasts",
    "Contact" : "Kontaktpersona",
    "Admin" : "Pārvaldītājs",
    "Owner" : "Īpašnieks",
    "Privacy" : "Privātums",
    "teams" : "komandas",
    "Detailed name" : "Izvērsts nosaukums",
    "Additional names" : "Papildu vārdi",
    "Prefix" : "Priedēklis",
    "Suffix" : "Piedēklis",
    "Nickname" : "Iesauka",
    "Notes" : "Piezīmes",
    "Website" : "Mājaslapa",
    "Location" : "Atrašanās vieta",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Mājas",
    "Work" : "Darbs",
    "Other" : "Cits",
    "Address" : "Adrese",
    "Post office box" : "Pasta kastīte",
    "Extended address" : "Paplašinātā adrese",
    "City" : "Pilsēta",
    "State or province" : "Štats vai apgabals",
    "Postal code" : "Pasta kods",
    "Country" : "Valsts",
    "Birthday" : "Dzimšanas diena",
    "Anniversary" : "Gadadiena",
    "Date of death" : "Miršanas datums",
    "Instant messaging" : "Tūlītējā ziņojumapmaiņa",
    "Phone" : "Tālrunis",
    "Mobile" : "Mobilais",
    "Work mobile" : "Darba mobīlais",
    "Home mobile" : "Mājas mobīlais",
    "Fax" : "Fakss",
    "Fax home" : "Fax mājās",
    "Fax work" : "Fax darbā",
    "Pager" : "Peidžeris",
    "Voice" : "Balss",
    "Car" : "Automašīna",
    "Work pager" : "Darba peidžeris",
    "Social network" : "Sociālais tīkls",
    "Spouse" : "Dzīvesbiedrs",
    "Child" : "Bērns",
    "Mother" : "Māte",
    "Father" : "Tēvs",
    "Parent" : "Vecāki",
    "Brother" : "Brālis",
    "Sister" : "Māsa",
    "Relative" : "Tuvinieks",
    "Friend" : "Draugs",
    "Colleague" : "Kolēģijas",
    "Assistant" : "Asistents",
    "Agent" : "Aģents",
    "Emergency" : "Ārkārtas gadījums",
    "Co-worker" : "Darba biedrs",
    "Gender" : "Dzimums",
    "Female" : "Sieviete",
    "Male" : "Vīrietis",
    "Unknown" : "Nezināms",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontaktpersonas neizdevās nolasīt","{failed} kontaktpersonu neizdevās nolasīt","{failed} kontaktpersonas neizdevās nolasīt"],
    "An error has occurred in team(s). Check the console for more details." : "Atgadījās kļūda komandā(s). Jāpārbauda konsole, lai iegūtu vairāk informācijas."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
